#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .max_vol_mag import max_vol_mag
from .vol_frac_cutoff import vol_frac_cutoff
class set_velocity_and_vof_cutoffs_child(Group):
    """
    'child_object_type' of set_velocity_and_vof_cutoffs.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['max_vol_mag', 'vol_frac_cutoff']

    max_vol_mag: max_vol_mag = max_vol_mag
    """
    max_vol_mag child of set_velocity_and_vof_cutoffs_child.
    """
    vol_frac_cutoff: vol_frac_cutoff = vol_frac_cutoff
    """
    vol_frac_cutoff child of set_velocity_and_vof_cutoffs_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable import enable
from .time_delay import time_delay
class particle_reinjector(Group):
    """
    'particle_reinjector' child.
    """

    fluent_name = "particle-reinjector"

    child_names = \
        ['enable', 'time_delay']

    enable: enable = enable
    """
    enable child of particle_reinjector.
    """
    time_delay: time_delay = time_delay
    """
    time_delay child of particle_reinjector.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .body_force_function import body_force_function
from .source_function import source_function
from .erosion_accretion_function import erosion_accretion_function
from .output_function import output_function
from .scalar_update_function import scalar_update_function
from .collision_function import collision_function
from .dpm_time_step_function import dpm_time_step_function
from .impingement_model_function import impingement_model_function
from .film_regime_function import film_regime_function
from .splashing_distribution_function import splashing_distribution_function
from .number_of_scalars import number_of_scalars
from .interpolation_function import interpolation_function
from .maximum_udf_species import maximum_udf_species
class user_defined_functions(Group):
    """
    Main menu to set DPM user-defined functions. User-defined functions can be used to customize the discrete phase model 
    to include additional body forces, modify interphase exchange terms (sources), calculate or integrate scalar values 
    along the particle trajectory, and more.
    """

    fluent_name = "user-defined-functions"

    child_names = \
        ['body_force_function', 'source_function',
         'erosion_accretion_function', 'output_function',
         'scalar_update_function', 'collision_function',
         'dpm_time_step_function', 'impingement_model_function',
         'film_regime_function', 'splashing_distribution_function',
         'number_of_scalars', 'interpolation_function',
         'maximum_udf_species']

    body_force_function: body_force_function = body_force_function
    """
    body_force_function child of user_defined_functions.
    """
    source_function: source_function = source_function
    """
    source_function child of user_defined_functions.
    """
    erosion_accretion_function: erosion_accretion_function = erosion_accretion_function
    """
    erosion_accretion_function child of user_defined_functions.
    """
    output_function: output_function = output_function
    """
    output_function child of user_defined_functions.
    """
    scalar_update_function: scalar_update_function = scalar_update_function
    """
    scalar_update_function child of user_defined_functions.
    """
    collision_function: collision_function = collision_function
    """
    collision_function child of user_defined_functions.
    """
    dpm_time_step_function: dpm_time_step_function = dpm_time_step_function
    """
    dpm_time_step_function child of user_defined_functions.
    """
    impingement_model_function: impingement_model_function = impingement_model_function
    """
    impingement_model_function child of user_defined_functions.
    """
    film_regime_function: film_regime_function = film_regime_function
    """
    film_regime_function child of user_defined_functions.
    """
    splashing_distribution_function: splashing_distribution_function = splashing_distribution_function
    """
    splashing_distribution_function child of user_defined_functions.
    """
    number_of_scalars: number_of_scalars = number_of_scalars
    """
    number_of_scalars child of user_defined_functions.
    """
    interpolation_function: interpolation_function = interpolation_function
    """
    interpolation_function child of user_defined_functions.
    """
    maximum_udf_species: maximum_udf_species = maximum_udf_species
    """
    maximum_udf_species child of user_defined_functions.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_3 import enabled
from .stream_id import stream_id
class track_single_particle_stream(Group):
    """
    'track_single_particle_stream' child.
    """

    fluent_name = "track-single-particle-stream"

    child_names = \
        ['enabled', 'stream_id']

    enabled: enabled = enabled
    """
    enabled child of track_single_particle_stream.
    """
    stream_id: stream_id = stream_id
    """
    stream_id child of track_single_particle_stream.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class steady_2way_fsi(Boolean):
    """
    Enable steady 2-way fsi workflow.
    """

    fluent_name = "steady-2way-fsi?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .auto_range_1 import auto_range
from .correlation import correlation
from .cumulation_curve import cumulation_curve
from .diameter_statistics import diameter_statistics
from .histogram_mode import histogram_mode
from .percentage import percentage
from .variable_3 import variable_3
from .logarithmic import logarithmic
from .weighting import weighting
class histogram_options(Group):
    """
    Enter the settings menu for the histogram.
    """

    fluent_name = "histogram-options"

    child_names = \
        ['auto_range', 'correlation', 'cumulation_curve',
         'diameter_statistics', 'histogram_mode', 'percentage', 'variable_3',
         'logarithmic', 'weighting']

    auto_range: auto_range = auto_range
    """
    auto_range child of histogram_options.
    """
    correlation: correlation = correlation
    """
    correlation child of histogram_options.
    """
    cumulation_curve: cumulation_curve = cumulation_curve
    """
    cumulation_curve child of histogram_options.
    """
    diameter_statistics: diameter_statistics = diameter_statistics
    """
    diameter_statistics child of histogram_options.
    """
    histogram_mode: histogram_mode = histogram_mode
    """
    histogram_mode child of histogram_options.
    """
    percentage: percentage = percentage
    """
    percentage child of histogram_options.
    """
    variable_3: variable_3 = variable_3
    """
    variable_3 child of histogram_options.
    """
    logarithmic: logarithmic = logarithmic
    """
    logarithmic child of histogram_options.
    """
    weighting: weighting = weighting
    """
    weighting child of histogram_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .type_1 import type
from .method_1 import method
from .specified_time_step import specified_time_step
from .incremental_time import incremental_time
from .max_iter_per_time_step import max_iter_per_time_step
from .time_step_count_1 import time_step_count
from .total_time_step_count import total_time_step_count
from .total_time import total_time
from .time_step_size import time_step_size
from .solution_status import solution_status
from .extrapolate_vars import extrapolate_vars
from .max_flow_time import max_flow_time
from .control_time_step_size_variation import control_time_step_size_variation
from .use_average_cfl import use_average_cfl
from .cfl_type import cfl_type
from .cfl_based_time_stepping import cfl_based_time_stepping
from .error_based_time_stepping import error_based_time_stepping
from .undo_timestep import undo_timestep
from .predict_next import predict_next
from .rotating_mesh_flow_predictor import rotating_mesh_flow_predictor
from .mp_specific_time_stepping import mp_specific_time_stepping
from .udf_hook import udf_hook
from .fixed_periodic_1 import fixed_periodic
from .duration_specification_method import duration_specification_method
from .multiphase_specific_time_constraints import multiphase_specific_time_constraints
from .solid_time_step_size import solid_time_step_size
from .time_step_size_for_acoustic_export import time_step_size_for_acoustic_export
from .extrapolate_eqn_vars import extrapolate_eqn_vars
class transient_controls(Group):
    """
    'transient_controls' child.
    """

    fluent_name = "transient-controls"

    child_names = \
        ['type', 'method', 'specified_time_step', 'incremental_time',
         'max_iter_per_time_step', 'time_step_count', 'total_time_step_count',
         'total_time', 'time_step_size', 'solution_status',
         'extrapolate_vars', 'max_flow_time',
         'control_time_step_size_variation', 'use_average_cfl', 'cfl_type',
         'cfl_based_time_stepping', 'error_based_time_stepping',
         'undo_timestep', 'predict_next', 'rotating_mesh_flow_predictor',
         'mp_specific_time_stepping', 'udf_hook', 'fixed_periodic',
         'duration_specification_method',
         'multiphase_specific_time_constraints', 'solid_time_step_size',
         'time_step_size_for_acoustic_export', 'extrapolate_eqn_vars']

    type: type = type
    """
    type child of transient_controls.
    """
    method: method = method
    """
    method child of transient_controls.
    """
    specified_time_step: specified_time_step = specified_time_step
    """
    specified_time_step child of transient_controls.
    """
    incremental_time: incremental_time = incremental_time
    """
    incremental_time child of transient_controls.
    """
    max_iter_per_time_step: max_iter_per_time_step = max_iter_per_time_step
    """
    max_iter_per_time_step child of transient_controls.
    """
    time_step_count: time_step_count = time_step_count
    """
    time_step_count child of transient_controls.
    """
    total_time_step_count: total_time_step_count = total_time_step_count
    """
    total_time_step_count child of transient_controls.
    """
    total_time: total_time = total_time
    """
    total_time child of transient_controls.
    """
    time_step_size: time_step_size = time_step_size
    """
    time_step_size child of transient_controls.
    """
    solution_status: solution_status = solution_status
    """
    solution_status child of transient_controls.
    """
    extrapolate_vars: extrapolate_vars = extrapolate_vars
    """
    extrapolate_vars child of transient_controls.
    """
    max_flow_time: max_flow_time = max_flow_time
    """
    max_flow_time child of transient_controls.
    """
    control_time_step_size_variation: control_time_step_size_variation = control_time_step_size_variation
    """
    control_time_step_size_variation child of transient_controls.
    """
    use_average_cfl: use_average_cfl = use_average_cfl
    """
    use_average_cfl child of transient_controls.
    """
    cfl_type: cfl_type = cfl_type
    """
    cfl_type child of transient_controls.
    """
    cfl_based_time_stepping: cfl_based_time_stepping = cfl_based_time_stepping
    """
    cfl_based_time_stepping child of transient_controls.
    """
    error_based_time_stepping: error_based_time_stepping = error_based_time_stepping
    """
    error_based_time_stepping child of transient_controls.
    """
    undo_timestep: undo_timestep = undo_timestep
    """
    undo_timestep child of transient_controls.
    """
    predict_next: predict_next = predict_next
    """
    predict_next child of transient_controls.
    """
    rotating_mesh_flow_predictor: rotating_mesh_flow_predictor = rotating_mesh_flow_predictor
    """
    rotating_mesh_flow_predictor child of transient_controls.
    """
    mp_specific_time_stepping: mp_specific_time_stepping = mp_specific_time_stepping
    """
    mp_specific_time_stepping child of transient_controls.
    """
    udf_hook: udf_hook = udf_hook
    """
    udf_hook child of transient_controls.
    """
    fixed_periodic: fixed_periodic = fixed_periodic
    """
    fixed_periodic child of transient_controls.
    """
    duration_specification_method: duration_specification_method = duration_specification_method
    """
    duration_specification_method child of transient_controls.
    """
    multiphase_specific_time_constraints: multiphase_specific_time_constraints = multiphase_specific_time_constraints
    """
    multiphase_specific_time_constraints child of transient_controls.
    """
    solid_time_step_size: solid_time_step_size = solid_time_step_size
    """
    solid_time_step_size child of transient_controls.
    """
    time_step_size_for_acoustic_export: time_step_size_for_acoustic_export = time_step_size_for_acoustic_export
    """
    time_step_size_for_acoustic_export child of transient_controls.
    """
    extrapolate_eqn_vars: extrapolate_eqn_vars = extrapolate_eqn_vars
    """
    extrapolate_eqn_vars child of transient_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .draw_major_rules import draw_major_rules
from .major_rule_weight import major_rule_weight
from .major_rule_line_color import major_rule_line_color
from .draw_minor_rules import draw_minor_rules
from .minor_rule_weight import minor_rule_weight
from .minor_rule_line_color import minor_rule_line_color
class x_axis(Group):
    """
    'x_axis' child.
    """

    fluent_name = "x-axis"

    child_names = \
        ['draw_major_rules', 'major_rule_weight', 'major_rule_line_color',
         'draw_minor_rules', 'minor_rule_weight', 'minor_rule_line_color']

    draw_major_rules: draw_major_rules = draw_major_rules
    """
    draw_major_rules child of x_axis.
    """
    major_rule_weight: major_rule_weight = major_rule_weight
    """
    major_rule_weight child of x_axis.
    """
    major_rule_line_color: major_rule_line_color = major_rule_line_color
    """
    major_rule_line_color child of x_axis.
    """
    draw_minor_rules: draw_minor_rules = draw_minor_rules
    """
    draw_minor_rules child of x_axis.
    """
    minor_rule_weight: minor_rule_weight = minor_rule_weight
    """
    minor_rule_weight child of x_axis.
    """
    minor_rule_line_color: minor_rule_line_color = minor_rule_line_color
    """
    minor_rule_line_color child of x_axis.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_12 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .flowrate_frac import flowrate_frac
from .elec_potential_type import elec_potential_type
from .potential_value import potential_value
from .dual_potential_type import dual_potential_type
from .dual_potential_value import dual_potential_value
from .x_displacement_type import x_displacement_type
from .x_displacement_value import x_displacement_value
from .y_displacement_type import y_displacement_type
from .y_displacement_value import y_displacement_value
from .z_displacement_type import z_displacement_type
from .z_displacement_value import z_displacement_value
from .uds_bc import uds_bc
from .uds import uds
from .radiation_bc import radiation_bc
from .coll_dtheta import coll_dtheta
from .coll_dphi import coll_dphi
from .band_q_irrad import band_q_irrad
from .band_q_irrad_diffuse import band_q_irrad_diffuse
from .parallel_collimated_beam import parallel_collimated_beam
from .solar_direction import solar_direction
from .solar_irradiation import solar_irradiation
from .t_b_b_spec import t_b_b_spec
from .t_b_b import t_b_b
from .in_emiss import in_emiss
from .dpm_bc_type import dpm_bc_type
from .dpm_bc_collision_partner import dpm_bc_collision_partner
from .reinj_inj import reinj_inj
from .dpm_bc_udf import dpm_bc_udf
from .solar_fluxes import solar_fluxes
from .solar_shining_factor import solar_shining_factor
from .radiating_s2s_surface import radiating_s2s_surface
class outflow_child(Group):
    """
    'child_object_type' of outflow.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'flowrate_frac',
         'elec_potential_type', 'potential_value', 'dual_potential_type',
         'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'uds_bc', 'uds', 'radiation_bc',
         'coll_dtheta', 'coll_dphi', 'band_q_irrad', 'band_q_irrad_diffuse',
         'parallel_collimated_beam', 'solar_direction', 'solar_irradiation',
         't_b_b_spec', 't_b_b', 'in_emiss', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'solar_fluxes', 'solar_shining_factor', 'radiating_s2s_surface']

    phase: phase = phase
    """
    phase child of outflow_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of outflow_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of outflow_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of outflow_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of outflow_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of outflow_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of outflow_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of outflow_child.
    """
    flowrate_frac: flowrate_frac = flowrate_frac
    """
    flowrate_frac child of outflow_child.
    """
    elec_potential_type: elec_potential_type = elec_potential_type
    """
    elec_potential_type child of outflow_child.
    """
    potential_value: potential_value = potential_value
    """
    potential_value child of outflow_child.
    """
    dual_potential_type: dual_potential_type = dual_potential_type
    """
    dual_potential_type child of outflow_child.
    """
    dual_potential_value: dual_potential_value = dual_potential_value
    """
    dual_potential_value child of outflow_child.
    """
    x_displacement_type: x_displacement_type = x_displacement_type
    """
    x_displacement_type child of outflow_child.
    """
    x_displacement_value: x_displacement_value = x_displacement_value
    """
    x_displacement_value child of outflow_child.
    """
    y_displacement_type: y_displacement_type = y_displacement_type
    """
    y_displacement_type child of outflow_child.
    """
    y_displacement_value: y_displacement_value = y_displacement_value
    """
    y_displacement_value child of outflow_child.
    """
    z_displacement_type: z_displacement_type = z_displacement_type
    """
    z_displacement_type child of outflow_child.
    """
    z_displacement_value: z_displacement_value = z_displacement_value
    """
    z_displacement_value child of outflow_child.
    """
    uds_bc: uds_bc = uds_bc
    """
    uds_bc child of outflow_child.
    """
    uds: uds = uds
    """
    uds child of outflow_child.
    """
    radiation_bc: radiation_bc = radiation_bc
    """
    radiation_bc child of outflow_child.
    """
    coll_dtheta: coll_dtheta = coll_dtheta
    """
    coll_dtheta child of outflow_child.
    """
    coll_dphi: coll_dphi = coll_dphi
    """
    coll_dphi child of outflow_child.
    """
    band_q_irrad: band_q_irrad = band_q_irrad
    """
    band_q_irrad child of outflow_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse = band_q_irrad_diffuse
    """
    band_q_irrad_diffuse child of outflow_child.
    """
    parallel_collimated_beam: parallel_collimated_beam = parallel_collimated_beam
    """
    parallel_collimated_beam child of outflow_child.
    """
    solar_direction: solar_direction = solar_direction
    """
    solar_direction child of outflow_child.
    """
    solar_irradiation: solar_irradiation = solar_irradiation
    """
    solar_irradiation child of outflow_child.
    """
    t_b_b_spec: t_b_b_spec = t_b_b_spec
    """
    t_b_b_spec child of outflow_child.
    """
    t_b_b: t_b_b = t_b_b
    """
    t_b_b child of outflow_child.
    """
    in_emiss: in_emiss = in_emiss
    """
    in_emiss child of outflow_child.
    """
    dpm_bc_type: dpm_bc_type = dpm_bc_type
    """
    dpm_bc_type child of outflow_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner = dpm_bc_collision_partner
    """
    dpm_bc_collision_partner child of outflow_child.
    """
    reinj_inj: reinj_inj = reinj_inj
    """
    reinj_inj child of outflow_child.
    """
    dpm_bc_udf: dpm_bc_udf = dpm_bc_udf
    """
    dpm_bc_udf child of outflow_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of outflow_child.
    """
    solar_shining_factor: solar_shining_factor = solar_shining_factor
    """
    solar_shining_factor child of outflow_child.
    """
    radiating_s2s_surface: radiating_s2s_surface = radiating_s2s_surface
    """
    radiating_s2s_surface child of outflow_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .value import value
from .piecewise_linear import piecewise_linear
from .piecewise_polynomial import piecewise_polynomial
from .polynomial import polynomial
from .expression import expression
from .biaxial import biaxial
from .cyl_orthotropic_1 import cyl_orthotropic
from .orthotropic_1 import orthotropic
from .principal_axes_values import principal_axes_values
from .anisotropic_1 import anisotropic
from .user_defined_function import user_defined_function
class thermal_conductivity(Group):
    """
    'thermal_conductivity' child.
    """

    fluent_name = "thermal-conductivity"

    child_names = \
        ['option', 'value', 'piecewise_linear', 'piecewise_polynomial',
         'polynomial', 'expression', 'biaxial', 'cyl_orthotropic',
         'orthotropic', 'principal_axes_values', 'anisotropic',
         'user_defined_function']

    option: option = option
    """
    option child of thermal_conductivity.
    """
    value: value = value
    """
    value child of thermal_conductivity.
    """
    piecewise_linear: piecewise_linear = piecewise_linear
    """
    piecewise_linear child of thermal_conductivity.
    """
    piecewise_polynomial: piecewise_polynomial = piecewise_polynomial
    """
    piecewise_polynomial child of thermal_conductivity.
    """
    polynomial: polynomial = polynomial
    """
    polynomial child of thermal_conductivity.
    """
    expression: expression = expression
    """
    expression child of thermal_conductivity.
    """
    biaxial: biaxial = biaxial
    """
    biaxial child of thermal_conductivity.
    """
    cyl_orthotropic: cyl_orthotropic = cyl_orthotropic
    """
    cyl_orthotropic child of thermal_conductivity.
    """
    orthotropic: orthotropic = orthotropic
    """
    orthotropic child of thermal_conductivity.
    """
    principal_axes_values: principal_axes_values = principal_axes_values
    """
    principal_axes_values child of thermal_conductivity.
    """
    anisotropic: anisotropic = anisotropic
    """
    anisotropic child of thermal_conductivity.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of thermal_conductivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_3 import enable
from .beams import beams
from .statistics import statistics
from .sampling_iterations import sampling_iterations
from .index_of_refraction import index_of_refraction
from .report import report
from .verbosity_2 import verbosity
class optics(Group):
    """
    Enter the optics model menu.
    """

    fluent_name = "optics"

    child_names = \
        ['enable', 'beams', 'statistics', 'sampling_iterations',
         'index_of_refraction', 'report', 'verbosity']

    enable: enable = enable
    """
    enable child of optics.
    """
    beams: beams = beams
    """
    beams child of optics.
    """
    statistics: statistics = statistics
    """
    statistics child of optics.
    """
    sampling_iterations: sampling_iterations = sampling_iterations
    """
    sampling_iterations child of optics.
    """
    index_of_refraction: index_of_refraction = index_of_refraction
    """
    index_of_refraction child of optics.
    """
    report: report = report
    """
    report child of optics.
    """
    verbosity: verbosity = verbosity
    """
    verbosity child of optics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .flux_child import flux_child

class flux(NamedObject[flux_child], _CreatableNamedObjectMixin[flux_child]):
    """
    'flux' child.
    """

    fluent_name = "flux"

    child_object_type: flux_child = flux_child
    """
    child_object_type of flux.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .thread_number_control import thread_number_control
from .check_verbosity_1 import check_verbosity
from .partition_1 import partition
from .set_4 import set
from .load_balance import load_balance
from .multidomain import multidomain
from .network_1 import network
from .timer import timer
from .check_1 import check
from .show_connectivity import show_connectivity
from .latency import latency
from .bandwidth import bandwidth
class parallel(Group):
    """
    'parallel' child.
    """

    fluent_name = "parallel"

    child_names = \
        ['thread_number_control', 'check_verbosity', 'partition', 'set',
         'load_balance', 'multidomain', 'network', 'timer']

    thread_number_control: thread_number_control = thread_number_control
    """
    thread_number_control child of parallel.
    """
    check_verbosity: check_verbosity = check_verbosity
    """
    check_verbosity child of parallel.
    """
    partition: partition = partition
    """
    partition child of parallel.
    """
    set: set = set
    """
    set child of parallel.
    """
    load_balance: load_balance = load_balance
    """
    load_balance child of parallel.
    """
    multidomain: multidomain = multidomain
    """
    multidomain child of parallel.
    """
    network: network = network
    """
    network child of parallel.
    """
    timer: timer = timer
    """
    timer child of parallel.
    """
    command_names = \
        ['check', 'show_connectivity', 'latency', 'bandwidth']

    check: check = check
    """
    check command of parallel.
    """
    show_connectivity: show_connectivity = show_connectivity
    """
    show_connectivity command of parallel.
    """
    latency: latency = latency
    """
    latency command of parallel.
    """
    bandwidth: bandwidth = bandwidth
    """
    bandwidth command of parallel.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .matrix_component import matrix_component
from .conductivity import conductivity
class anisotropic(Group):
    """
    'anisotropic' child.
    """

    fluent_name = "anisotropic"

    child_names = \
        ['matrix_component', 'conductivity']

    matrix_component: matrix_component = matrix_component
    """
    matrix_component child of anisotropic.
    """
    conductivity: conductivity = conductivity
    """
    conductivity child of anisotropic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class film_vof_trans_low_relax(Real):
    """
    'film_vof_trans_low_relax' child.
    """

    fluent_name = "film-vof-trans-low-relax"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .smoothed_density_stabilization_method import smoothed_density_stabilization_method
from .num_of_density_smoothing import num_of_density_smoothing
from .false_time_step_linearization import false_time_step_linearization
from .auto_dt_advanced_controls import auto_dt_advanced_controls
class pseudo_transient(Group):
    """
    Pseudo-Time stability controls for multiphase flow.
    """

    fluent_name = "pseudo-transient"

    child_names = \
        ['smoothed_density_stabilization_method', 'num_of_density_smoothing',
         'false_time_step_linearization', 'auto_dt_advanced_controls']

    smoothed_density_stabilization_method: smoothed_density_stabilization_method = smoothed_density_stabilization_method
    """
    smoothed_density_stabilization_method child of pseudo_transient.
    """
    num_of_density_smoothing: num_of_density_smoothing = num_of_density_smoothing
    """
    num_of_density_smoothing child of pseudo_transient.
    """
    false_time_step_linearization: false_time_step_linearization = false_time_step_linearization
    """
    false_time_step_linearization child of pseudo_transient.
    """
    auto_dt_advanced_controls: auto_dt_advanced_controls = auto_dt_advanced_controls
    """
    auto_dt_advanced_controls child of pseudo_transient.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .display_3 import display
from .history_filename import history_filename
from .report_default_variables import report_default_variables
from .track_single_particle_stream_1 import track_single_particle_stream
from .arrow_scale_1 import arrow_scale
from .arrow_space_1 import arrow_space
from .coarsen_factor import coarsen_factor
from .line_width_1 import line_width
class particle_tracks(Group):
    """
    'particle_tracks' child.
    """

    fluent_name = "particle-tracks"

    child_names = \
        ['display', 'history_filename', 'report_default_variables',
         'track_single_particle_stream', 'arrow_scale', 'arrow_space',
         'coarsen_factor', 'line_width']

    display: display = display
    """
    display child of particle_tracks.
    """
    history_filename: history_filename = history_filename
    """
    history_filename child of particle_tracks.
    """
    report_default_variables: report_default_variables = report_default_variables
    """
    report_default_variables child of particle_tracks.
    """
    track_single_particle_stream: track_single_particle_stream = track_single_particle_stream
    """
    track_single_particle_stream child of particle_tracks.
    """
    arrow_scale: arrow_scale = arrow_scale
    """
    arrow_scale child of particle_tracks.
    """
    arrow_space: arrow_space = arrow_space
    """
    arrow_space child of particle_tracks.
    """
    coarsen_factor: coarsen_factor = coarsen_factor
    """
    coarsen_factor child of particle_tracks.
    """
    line_width: line_width = line_width
    """
    line_width child of particle_tracks.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .sbes_sdes_hybrid_model_optn import sbes_sdes_hybrid_model_optn
from .user_defined_fcn_for_sbes import user_defined_fcn_for_sbes
class sbes_sdes_hybrid_model(Group):
    """
    'sbes_sdes_hybrid_model' child.
    """

    fluent_name = "sbes-sdes-hybrid-model"

    child_names = \
        ['sbes_sdes_hybrid_model_optn', 'user_defined_fcn_for_sbes']

    sbes_sdes_hybrid_model_optn: sbes_sdes_hybrid_model_optn = sbes_sdes_hybrid_model_optn
    """
    sbes_sdes_hybrid_model_optn child of sbes_sdes_hybrid_model.
    """
    user_defined_fcn_for_sbes: user_defined_fcn_for_sbes = user_defined_fcn_for_sbes
    """
    user_defined_fcn_for_sbes child of sbes_sdes_hybrid_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .convergence_acceleration_type import convergence_acceleration_type
from .casm_cutoff_multiplier import casm_cutoff_multiplier
class convergence_acceleration_for_stretched_meshes(Group):
    """
    Enable convergence acceleration for stretched meshes to improve the convergence of the implicit density based solver on meshes with high cell stretching.
    """

    fluent_name = "convergence-acceleration-for-stretched-meshes"

    child_names = \
        ['convergence_acceleration_type', 'casm_cutoff_multiplier']

    convergence_acceleration_type: convergence_acceleration_type = convergence_acceleration_type
    """
    convergence_acceleration_type child of convergence_acceleration_for_stretched_meshes.
    """
    casm_cutoff_multiplier: casm_cutoff_multiplier = casm_cutoff_multiplier
    """
    casm_cutoff_multiplier child of convergence_acceleration_for_stretched_meshes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .across_zones import across_zones
from .method_1 import method
from .load_vector import load_vector
from .pre_test import pre_test
from .use_case_file_method import use_case_file_method
class auto(Group):
    """
    Enter the menu to set auto partition parameters.
    """

    fluent_name = "auto"

    child_names = \
        ['across_zones', 'method', 'load_vector', 'pre_test']

    across_zones: across_zones = across_zones
    """
    across_zones child of auto.
    """
    method: method = method
    """
    method child of auto.
    """
    load_vector: load_vector = load_vector
    """
    load_vector child of auto.
    """
    pre_test: pre_test = pre_test
    """
    pre_test child of auto.
    """
    command_names = \
        ['use_case_file_method']

    use_case_file_method: use_case_file_method = use_case_file_method
    """
    use_case_file_method command of auto.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class old_variant_of_pesto_for_cases_using_structured_mesh(Boolean):
    """
    'old_variant_of_pesto_for_cases_using_structured_mesh' child.
    """

    fluent_name = "old-variant-of-pesto-for-cases-using-structured-mesh"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .total_period_count import total_period_count
from .time_step_count_1 import time_step_count
from .total_time_step_count import total_time_step_count
from .total_time import total_time
from .incremental_time import incremental_time
from .max_iter_per_step import max_iter_per_step
from .postprocess import postprocess
from .post_iter_per_time_step_count import post_iter_per_time_step_count
class dual_time_iterate(Command):
    """
    Perform unsteady iterations.
    
    Parameters
    ----------
        total_period_count : int
            Set number of total periods.
        time_step_count : int
            Set inceremtal number of Time steps.
        total_time_step_count : int
            Set total number of Time steps.
        total_time : real
            Set Total Simulation Time.
        incremental_time : real
            Set Incremental Time.
        max_iter_per_step : int
            Set Maximum Number of iterations per time step.
        postprocess : bool
            Enable/Disable Postprocess pollutant solution?.
        post_iter_per_time_step_count : int
            Set Number of post-processing iterations per time step.
    
    """

    fluent_name = "dual-time-iterate"

    argument_names = \
        ['total_period_count', 'time_step_count', 'total_time_step_count',
         'total_time', 'incremental_time', 'max_iter_per_step', 'postprocess',
         'post_iter_per_time_step_count']

    total_period_count: total_period_count = total_period_count
    """
    total_period_count argument of dual_time_iterate.
    """
    time_step_count: time_step_count = time_step_count
    """
    time_step_count argument of dual_time_iterate.
    """
    total_time_step_count: total_time_step_count = total_time_step_count
    """
    total_time_step_count argument of dual_time_iterate.
    """
    total_time: total_time = total_time
    """
    total_time argument of dual_time_iterate.
    """
    incremental_time: incremental_time = incremental_time
    """
    incremental_time argument of dual_time_iterate.
    """
    max_iter_per_step: max_iter_per_step = max_iter_per_step
    """
    max_iter_per_step argument of dual_time_iterate.
    """
    postprocess: postprocess = postprocess
    """
    postprocess argument of dual_time_iterate.
    """
    post_iter_per_time_step_count: post_iter_per_time_step_count = post_iter_per_time_step_count
    """
    post_iter_per_time_step_count argument of dual_time_iterate.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .face_pressure_options import face_pressure_options
class face_pressure_controls(Group):
    """
    Enter the face pressure expert controls menu.
    """

    fluent_name = "face-pressure-controls"

    child_names = \
        ['face_pressure_options']

    face_pressure_options: face_pressure_options = face_pressure_options
    """
    face_pressure_options child of face_pressure_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .name import name
class fast_solution(Command):
    """
    Write a FAST/Plot3D unstructured solution file.
    
    Parameters
    ----------
        name : str
            'name' child.
    
    """

    fluent_name = "fast-solution"

    argument_names = \
        ['name']

    name: name = name
    """
    name argument of fast_solution.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .radiator_child import radiator_child

class radiator(NamedObject[radiator_child], _NonCreatableNamedObjectMixin[radiator_child]):
    """
    'radiator' child.
    """

    fluent_name = "radiator"

    child_object_type: radiator_child = radiator_child
    """
    child_object_type of radiator.
    """



from collections import OrderedDict


class _UnitsTable(object):
    fundamental_units = {
        "kg": "M",
        "g": "M",
        "lb": "M",
        "lbm": "M",
        "slug": "M",
        "m": "L",
        "cm": "L",
        "ft": "L",
        "in": "L",
        "s": "T",
        "A": "I",
        "K": "Temp",
        "C": "Temp",
        "F": "Temp",
        "R": "Temp",
        "mol": "N",
        "slugmol": "N",
        "cd": "Iv",
        "sr": "SAngle",
        "radian": "Angle",
        "degree": "Angle",
    }

    derived_units = {
        "N": "kg m s^-2",
        "Pa": "N m^-2",
        "W": "N m s^-1",
        "J": "N m",
        "V": "A ohm",
        "farad": "N m V^-2",
        "H": "N m A^-2",
        "S": "ohm^-1",
        "Wb": "N m A^-1",
        "T": "Wb m^-2",
        "dyne": "g cm s^-2",
        "erg": "dyne cm",
        "pdl": "lbm ft s^-2",
        "BTU": "J",
        "psi": "lbf in^-2",
        "lbf": "slug ft s^-2",
        "psf": "lbf ft^-2",
        "ohm": "kg m^2 s^-3 A^-2",
        "Hz": "s^-1",
        "cal": "J",
        "delta_K": "K",
        "delta_C": "C",
        "delta_F": "F",
        "delta_R": "R",
        "coulomb": "A s",
    }

    derived_units_with_conversion_factor = {
        "l": (0.001, "m^3"),
        "gal": (0.0037854117839999993, "m^3"),
        "BTU": (1055.056, "J"),
        "cal": (4.184, "J"),
    }

    multipliers = {
        "d": 10**-1,
        "c": 10**-2,
        "m": 10**-3,
        "u": 10**-6,
        "n": 10**-9,
        "p": 10**-12,
        "f": 10**-15,
        "a": 10**-18,
        "z": 10**-21,
        "y": 10**-24,
        "da": 10**1,
        "h": 10**2,
        "k": 10**3,
        "M": 10**6,
        "G": 10**9,
        "T": 10**12,
        "P": 10**15,
        "E": 10**18,
        "Z": 10**21,
        "Y": 10**24,
    }

    dimension_order = OrderedDict(
        [
            ("Mass", "M"),
            ("Length", "L"),
            ("Time", "T"),
            ("Temperature", "Temp"),
            ("Angle", "Angle"),
            ("ChemicalAmount", "N"),
            ("Light", "Iv"),
            ("Current", "I"),
            ("SolidAngle", "SAngle"),
            ("", ""),
        ]
    )

    conversion_map = {
        "kg": 1,
        "g": 0.001,
        "lb": 0.45359237,
        "lbm": 0.45359237,
        "slug": 14.59390293720637,
        "m": 1,
        "cm": 0.01,
        "ft": 0.30479999999999996,
        "in": 0.0254,
        "s": 1,
        "A": 1,
        "mol": 1,
        "slugmol": 14593.9,
        "cd": 1,
        "sr": 1,
        "radian": 1,
        "degree": 0.017453292519943295,
        "K": 1,
        "C": 1,
        "F": 0.5555555555555556,
        "R": 0.5555555555555556,
        "delta_K": 1,
        "delta_C": 1,
        "delta_F": 0.5555555555555556,
        "delta_R": 0.5555555555555556,
    }

    si_map = {
        "kg": "kg",
        "g": "kg",
        "lb": "kg",
        "lbm": "kg",
        "slug": "kg",
        "m": "m",
        "cm": "m",
        "ft": "m",
        "in": "m",
        "s": "s",
        "A": "A",
        "mol": "mol",
        "slugmol": "mol",
        "cd": "cd",
        "sr": "sr",
        "radian": "radian",
        "degree": "radian",
        "K": "K",
        "C": "K",
        "F": "K",
        "R": "K",
        "": "",
    }

    temperature_conversions = {
        # from : { to : formula }
        "C": {
            "K": lambda c: c + 273.15,
            "R": lambda c: (c + 273.15) * 1.8,
            "F": lambda c: c * 9 / 5 + 32,
            "C": lambda c: c,
        },
        "F": {
            "K": lambda f: (f - 32) * 5 / 9 + 273.15,
            "R": lambda f: f + 459.67,
            "F": lambda f: f,
            "C": lambda f: (f - 32) * 5 / 9,
        },
        "R": {
            "K": lambda r: r / 1.8,
            "R": lambda r: r,
            "F": lambda r: r - 459.67,
            "C": lambda r: (r - 491.67) / 1.8,
        },
        "K": {
            "K": lambda k: k,
            "R": lambda k: k * 1.8,
            "F": lambda k: k * 1.8 - 459.67,
            "C": lambda k: k - 273.15,
        },
    }


def get_si_conversion_factor(unit_str):
    return (
        _UnitsTable.conversion_map[unit_str]
        if unit_str in _UnitsTable.conversion_map.keys()
        else 1
    )


def filter_multiplier(unit_str, predicate=None):
    result = False
    matched = ""
    for item in _UnitsTable.multipliers.keys():
        result = predicate(item, unit_str) if predicate else item == unit_str
        if result:
            matched = item
            result = True
            temp_unit_str = unit_str[len(item) :]
            if (
                temp_unit_str in _UnitsTable.fundamental_units
                or temp_unit_str in _UnitsTable.derived_units
            ):
                break
            else:
                result = False
                continue
    return result, matched


def remove_multiplier(unit_str):
    has_multiplier, prefix = filter_multiplier(
        unit_str, lambda item, unit: len(unit) > 0.0 and unit.startswith(item)
    )
    if has_multiplier:
        unit_str = unit_str[len(prefix) :]
    return unit_str


def is_temperature_quantity(dim_obj):
    temp_dim = dim_obj["Temp"]
    total_dims_sum = sum([abs(val) for val in dim_obj.values()])
    return temp_dim == 1 and total_dims_sum == temp_dim


class Unit(object):
    def __init__(self, unit_str):
        self._unit = unit_str
        self._si_multiplier = 1
        self._si_offset = 0
        self._si_unit = ""
        self._offset_power = 1
        self._compute_multipliers(unit_str, 1)
        self._compute_offset(unit_str)
        self._reduce_to_si_unit(self._si_unit)

    @property
    def user_unit(self):
        return self._unit

    @property
    def si_factor(self):
        return self._si_multiplier

    @property
    def si_unit(self):
        return self._si_unit

    @property
    def si_offset(self):
        return self._si_offset

    @property
    def offset_power(self):
        return self._offset_power

    def __call__(self):
        return self.user_unit

    def _reduce_to_si_unit(self, unit_str):
        term_power_dict = OrderedDict()
        unit_split = unit_str.split(" ")

        for term in unit_split:
            if "^" in term:
                term_split = term.split("^")
                if term_split[0] in term_power_dict.keys():
                    term_power_dict[term_split[0]] += float(term_split[1])
                else:
                    term_power_dict[term_split[0]] = float(term_split[1])
            else:
                if term in term_power_dict.keys():
                    term_power_dict[term] += 1.0
                else:
                    term_power_dict[term] = 1.0

        self._si_unit = ""

        for key, power in term_power_dict.items():
            spacechar = " " if len(self._si_unit) > 0 else ""

            if power == 1.0:
                self._si_unit += spacechar + key
            elif power != 0.0:
                self._si_unit += (
                    spacechar
                    + key
                    + "^"
                    + str(int(power) if power.is_integer() else power)
                )
            else:
                self._si_unit += spacechar + key

    def _compute_multipliers(self, unit_str, power):
        if len(unit_str) == 0:
            return

        unit_list = unit_str.split(" ")

        for term in unit_list:
            unit_str = term
            term_power = 1

            if "^" in unit_str:
                unit_str, term_power = unit_str[: unit_str.index("^")], float(
                    unit_str[unit_str.index("^") + 1 :]
                )

            term_power *= power
            has_multiplier = not (
                unit_str in _UnitsTable.fundamental_units
                or unit_str in _UnitsTable.derived_units
            )

            if has_multiplier:
                _, prefix = filter_multiplier(
                    unit_str,
                    lambda item, unit: len(unit) > 0.0 and unit.startswith(item),
                )

                if len(prefix):
                    self._si_multiplier *= _UnitsTable.multipliers[prefix] ** term_power

                unit_str = remove_multiplier(unit_str)

            if unit_str in _UnitsTable.fundamental_units:
                spacechar = " " if len(self._si_unit) > 0 else ""

                if term_power == 1.0:
                    self._si_unit += spacechar + _UnitsTable.si_map[unit_str]
                elif term_power != 0.0:
                    self._si_unit += (
                        spacechar + _UnitsTable.si_map[unit_str] + "^" + str(term_power)
                    )
                elif term_power == 0.0:
                    self._si_unit += ""
                else:
                    self._si_unit += spacechar + _UnitsTable.si_map[unit_str]

                self._si_multiplier *= get_si_conversion_factor(unit_str) ** term_power

            elif unit_str in _UnitsTable.derived_units_with_conversion_factor:
                (
                    conversion_factor,
                    unit_str,
                ) = _UnitsTable.derived_units_with_conversion_factor[unit_str]
                self._si_multiplier *= conversion_factor**term_power
                self._compute_multipliers(unit_str, term_power)
            elif unit_str in _UnitsTable.derived_units:
                self._compute_multipliers(
                    _UnitsTable.derived_units[unit_str], term_power
                )

    @staticmethod
    def _power_sum(base, unit_str):
        if unit_str in ["K", "C", "F", "R"]:
            if "^" in unit_str:
                return sum(
                    [
                        float(term.split("^")[1])
                        for term in unit_str.split(" ")
                        if term.split("^")[0] == base
                    ]
                )
            else:
                return 1.0

    def _compute_offset(self, unit_str):
        if unit_str == "C":
            self._si_offset = 273.15
            self._offset_power = self._power_sum("C", unit_str)
        elif unit_str == "F":
            self._si_offset = 255.3722
            self._offset_power = self._power_sum("F", unit_str)
        else:
            self._si_offset = 0
            self._offset_power = 1.0

    def _quantity_type(self):
        temperature_units = ["K", "C", "F", "R"]
        qty_type = None
        for temp_unit in temperature_units:
            unit_power = Unit._power_sum(temp_unit, self._unit)
            if temp_unit in self._unit and unit_power == 1.0:
                qty_type = "Temperature"
            elif "delta_" in self._unit:
                qty_type = "Temperature Difference"
            elif temp_unit in self._unit and unit_power not in [0.0, 1.0]:
                qty_type = "Temperature Difference"
        return qty_type


class Dimension(object):
    def __init__(self, unit_str):
        self._dimensions = {
            "M": 0.0,
            "L": 0.0,
            "T": 0.0,
            "Temp": 0.0,
            "I": 0.0,
            "N": 0.0,
            "Iv": 0.0,
            "Angle": 0.0,
            "SAngle": 0.0,
            "": 0.0,
        }
        self._parser(unit_str)

    def _add_or_update_dimension(self, dim_dict):
        for key in dim_dict.keys():
            self._dimensions[key] += dim_dict[key]

    def _parser(self, unit, power=1):
        if len(unit) == 0:
            return

        unit_list = unit.split(" ")
        for term in unit_list:
            unit_dim = ""
            has_multiplier = not (
                term in _UnitsTable.fundamental_units
                or term in _UnitsTable.derived_units
            )
            unit_str = remove_multiplier(term) if has_multiplier else term
            term_power = 1

            if "^" in term:
                unit_str, term_power = term[: term.index("^")], float(
                    term[term.index("^") + 1 :]
                )
                has_multiplier = not (
                    unit_str in _UnitsTable.fundamental_units
                    or unit_str in _UnitsTable.derived_units
                )
                unit_str = remove_multiplier(unit_str) if has_multiplier else unit_str

            term_power *= power
            unit_dim = self._get_dim(unit_str, term_power)

            if unit_dim != None:
                self._add_or_update_dimension(unit_dim)

    def as_dict(self):
        return self._dimensions

    def _get_dim(self, unit_str, power):
        if unit_str in _UnitsTable.fundamental_units:
            return {_UnitsTable.fundamental_units[unit_str]: power}
        elif unit_str in _UnitsTable.derived_units:
            self._parser(_UnitsTable.derived_units[unit_str], power)
        elif unit_str in _UnitsTable.derived_units_with_conversion_factor:
            _, unit_str = _UnitsTable.derived_units_with_conversion_factor[unit_str]
            self._parser(unit_str, power)
        else:
            raise ValueError("Not implemented")


def get_si_unit_from_dim(dim_list):
    si_unit = ""
    dim_to_unit_map = UnitSystem("SI").base_units()

    for key, power in zip(_UnitsTable.dimension_order.values(), dim_list):
        unit_str = dim_to_unit_map[key]
        spacechar = " " if len(si_unit) > 0 else ""
        if power == 1.0:
            si_unit += spacechar + unit_str
        elif power != 0.0:
            si_unit += (
                spacechar
                + unit_str
                + "^"
                + str(int(power) if power.is_integer() else power)
            )
    return si_unit


class UnitSystem:

    _dim_to_unit_sys_map = {
        "SI": {
            "M": "kg",
            "L": "m",
            "T": "s",
            "Temp": "K",
            "I": "A",
            "N": "mol",
            "Iv": "cd",
            "Angle": "radian",
            "SAngle": "sr",
            "": "",
        },
        "CGS": {
            "M": "g",
            "L": "cm",
            "T": "s",
            "Temp": "K",
            "I": "A",
            "N": "mol",
            "Iv": "cd",
            "Angle": "radian",
            "SAngle": "sr",
            "": "",
        },
        "BT": {
            "M": "slug",
            "L": "ft",
            "T": "s",
            "Temp": "R",
            "I": "A",
            "N": "slugmol",
            "Iv": "cd",
            "Angle": "radian",
            "SAngle": "sr",
            "": "",
        },
    }

    _supported_unit_sys = ("SI", "CGS", "BT")

    def __init__(self, unit_sys):
        self._unit_system = unit_sys.upper()

        if self._unit_system not in UnitSystem._supported_unit_sys:
            raise ValueError(
                "Unsupported unit system, only 'SI', 'CGS', 'BT' is allowed."
            )

    def _get_unit_from_dim(self, dim_list):
        unit = ""

        base_units = UnitSystem._dim_to_unit_sys_map[self._unit_system]
        for key, power in zip(_UnitsTable.dimension_order.values(), dim_list):
            spacechar = " " if len(unit) > 0 else ""
            if power == 1:
                unit += spacechar + base_units[key]
            elif power != 0:
                unit += (
                    spacechar
                    + base_units[key]
                    + "^"
                    + str(int(power) if power.is_integer() else power)
                )
        return unit

    def convert(self, quantity):
        if not isinstance(quantity, Quantity):
            raise TypeError("Not instance of Quantity.")
        dims = quantity.get_dimensions_list()
        unit_str = self._get_unit_from_dim(dims)
        return quantity.to(unit_str)

    def base_units(self):
        return UnitSystem._dim_to_unit_sys_map[self._unit_system]


class QuantityError(ValueError):
    def __init__(self, from_unit, to_unit):
        self.from_unit = from_unit
        self.to_unit = to_unit

    def __str__(self):
        return f"{self.unit} and {self.to_unit} have incompatible dimensions."


unit_quantity_map = {
    "Mass": "kg",
    "Length": "m",
    "Time": "s",
    "Temperature": "K",
    "Current": "A",
    "SubstanceAmount": "mol",
    "Light": "cd",
    "Angle": "radian",
    "SolidAngle": "sr",
    "Acceleration": "m s^-2",
    "Angular Acceleration": "radian s^-2",
    "Angular Velocity": "radian s^-1",
    "Area": "m^2",
    "Capacitance": "farad",
    "Compressibility": "Pa^-1",
    "Concentration": "m^-3",
    "Contact Resistance": "m^2 s kg^-1",
    "Current Transfer Coefficient": "A m^-2 V^-1",
    "Decay Constant": "s^-1",
    "Density": "kg m^-3",
    "Density Derivative": "m^-2 s^2",
    "Density Derivative wrt Pressure": "m^-2 s^2",
    "Density Derivative wrt Temperature": "kg m^-3 K^-1",
    "Dielectric Contact Resistance": "farad^-1 m^2",
    "Dynamic Viscosity": "Pa s",
    "Electric Charge": "A s",
    "Electric Charge Density": "A s m^-3",
    "Electric Charge Transfer Coefficient": "farad m^-2",
    "Electric Conductance Per Unit Area": "S m^-2",
    "Electric Current Density": "A m^-2",
    "Electric Current Source": "A m^-3",
    "Electric Field": "V m^-1",
    "Electric Flux Density": "coulomb m^-2",
    "Electrical Conductance": "S",
    "Electrical Conductivity": "S m^-1",
    "Electrical Contact Resistance": "S^-1 m^2",
    "Electrical Permittivity": "A s V^-1 m^-1",
    "Electrical Resistance": "ohm",
    "Electrical Resistivity": "ohm m",
    "Energy Density by Mass": "J kg^-1",
    "Energy Source": "W m^-3",
    "Energy Source Coefficient": "W m^-3 K^-1",
    "Enthalpy Variance": "m^4 s^-4",
    "Epsilon": "m^2 s^-3",
    "Epsilon Flux": "W m^-2 s^-1",
    "Epsilon Flux Coefficient": "kg m^-2 s^-2",
    "Epsilon Source": "W m^-3 s^-1",
    "Epsilon Source Coefficient": "kg m^-3 s^-2",
    "Flame Surface Density Source": "m^-1 s^-1",
    "Force": "N",
    "Force Density": "N m^-3",
    "Force Intensity": "N m^-1",
    "Force Per Angular Unit": "N radian^-1",
    "Fracture Energy": "J m^-2",
    "Fracture Energy Rate": "J m^-2 s^-1",
    "Frequency": "Hz",
    "Gasket Stiffness": "Pa m^-1",
    "Heat Flux": "W m^-2",
    "Heat Flux in": "W m^-2",
    "Heat Generation": "W m^-3",
    "Heat Rate": "W",
    "Heat Transfer Coefficient": "W m^-2 K^-1",
    "Impulse": "N s",
    "Impulse Per Angular Unit": "N s radian^-1",
    "Inductance": "H",
    "Interphase Transfer Coefficient": "kg m^-2 s^-1",
    "InvTemp1": "K^-1",
    "InvTemp2": "K^-2",
    "InvTemp3": "K^-3",
    "InvTemp4": "K^-4",
    "Inverse Angle": "radian^-1",
    "Inverse Area": "m^-2",
    "Inverse Length": "m^-1",
    "Inverse Stress": "Pa^-1",
    "Kinematic Diffusivity": "m^2 s^-1",
    "MAPDL Enthalpy": "J m^-3",
    "Magnetic Field": "A m^-1",
    "Magnetic Field Intensity": "A m^-1",
    "Magnetic Flux": "Wb",
    "Magnetic Flux Density": "T",
    "Magnetic Induction": "T",
    "Magnetic Permeability": "H m^-1",
    "Magnetic Potential": "T m",
    "Mass Concentration": "kg m^-3",
    "Mass Concentration Rate": "kg m^-3 s^-1",
    "Mass Flow": "kg s^-1",
    "Mass Flow Rate Per Area": "kg s^-1 m^-2",
    "Mass Flow Rate Per Length": "kg s^-1 m^-1",
    "Mass Flow Rate Per Volume": "kg s^-1 m^-3",
    "Mass Flow in": "kg s^-1",
    "Mass Flux": "kg s^-1 m^-2",
    "Mass Flux Coefficient": "kg s^-1 m^-2",
    "Mass Flux Pressure Coefficient": "kg s^-1 m^-2 Pa^-1",
    "Mass Fraction": "kg kg^-1",
    "Mass Per Area": "kg m^-2",
    "Mass Source": "kg s^-1 m^-3",
    "Mass Source Coefficient": "kg s^-1 m^-3 Pa^-1",
    "Material Impedance": "kg m^-2 s^-1",
    "Molar Concentration": "mol m^-3",
    "Molar Concentration Henry Coefficient": "Pa m^3 mol^-1",
    "Molar Concentration Rate": "mol m^-3 s^-1",
    "Molar Energy": "J mol^-1",
    "Molar Entropy": "J mol^-1 K^-1",
    "Molar Fraction": "mol mol^-1",
    "Molar Mass": "kg kmol^-1",
    "Molar Volume": "m^3 mol^-1",
    "Moment": "N m",
    "Moment of Inertia of Area": "m^2 m^2",
    "Moment of Inertia of Mass": "kg m^2",
    "Momentum Source": "kg m^-2 s^-2",
    "Momentum Source Lin Coeff": "kg m^-3 s^-1",
    "Momentum Source Quad Coeff": "kg m^-4",
    "Normalized Value": "m m^-1",
    "Number Source": "m^-3 s^-1",
    "Omega Source": "kg m^-3 s^-2",
    "PSD Acceleration": "m^2 s^-4 Hz^-1",
    "PSD Displacement": "m^2 Hz^-1",
    "PSD Force": "N^2 Hz^-1",
    "PSD Moment": "N^2 m^2 Hz^-1",
    "PSD Pressure": "Pa^2 Hz^-1",
    "PSD Strain": "m^2 m^-2 Hz^-1",
    "PSD Stress": "Pa^2 Hz^-1",
    "PSD Velocity": "m^2 s^-2 Hz^-1",
    "Per Mass": "kg^-1",
    "Per Mass Flow": "s kg^-1",
    "Per Time": "s^-1",
    "Per Time Cubed": "s^-3",
    "Per Time Squared": "s^-2",
    "Power Spectral Density": "W Hz^-1",
    "Pressure": "Pa",
    "Pressure Derivative wrt Temperature": "Pa K^-1",
    "Pressure Derivative wrt Volume": "Pa kg m^-3",
    "Pressure Gradient": "Pa m^-1",
    "Relative Permeability": "H H^-1",
    "Relative Permittivity": "farad farad^-1",
    "Rotational Damping": "N m s radian^-1",
    "Rotational Stiffness": "N m radian^-1",
    "Section Modulus": "m^3",
    "Seebeck Coefficient": "V K^-1",
    "Shear Strain": "radian",
    "Shear Strain Rate": "s^-1",
    "Shock Velocity": "s m^-1",
    "Soot Cross Coefficient": "m^3 mol^-1 s^-1",
    "Soot PX Facto": "mol kg^-1 s^-1",
    "Specific": "kg kg^-1",
    "Specific Concentration": "mol kg^-1",
    "Specific Energy": "J kg^-1",
    "Specific Enthalpy": "J kg^-1",
    "Specific Entropy": "J kg^-1 K^-1",
    "Specific Flame Surface Density": "m^2 kg^-1",
    "Specific Heat Capacity": "J kg^-1 K^-1",
    "Specific Volume": "kg^-1 m^3",
    "Specific Weight": "N m^-3",
    "Stiffness": "N m^-1",
    "Strain": "m m^-1",
    "Strength": "Pa",
    "Stress": "Pa",
    "Stress Intensity Factor": "Pa m^0.5",
    "Stress Per Temperature": "Pa K^-1",
    "Surface Charge Density": "A s m^-2",
    "Surface Force Density": "N m^-2",
    "Surface Power Density": "W m^-2",
    "Surface Tension": "N m^-1",
    "Temperature Difference": "delta_K",
    "Temperature Gradient": "K m^-1",
    "Temperature Variance": "K^2",
    "Temperature Variance Source": "kg m^-3 s^-1 K^2",
    "Thermal Capacitance": "J K^-1",
    "Thermal Conductance": "W K^-1",
    "Thermal Conductivity": "W m^-1 K^-1",
    "Thermal Contact Resistance": "W^-1 m^2 K",
    "Thermal Expansivity": "K^-1",
    "Torque": "N m",
    "Torsional Spring Constant": "N m radian^-1",
    "Total Mass Source Pressure Coefficient": "kg s^-1 Pa^-1",
    "Total Radiative Intensity": "W m^-2 sr^-1",
    "Translational Damping": "N s m^-1",
    "Turbulent Heat Flux": "m^3 s^-3",
    "Velocity": "m s^-1",
    "Volume": "m^3",
    "Volumetric": "kg m^-3",
    "Volumetric Flow": "m^3 s^-1",
    "Volumetric Flow in": "m^3 s^-1",
    "Warping Factor": "m^6",
}


def get_unit_from_map(quantity_map_from_settings_api):
    terms = []
    term_power_list = []
    final_unit = ""
    for unit in quantity_map_from_settings_api.keys():
        unit_str = unit_quantity_map[unit]
        unit_term_list = unit_str.split(" ") if " " in unit_str else unit_str
        term_power_list.append(unit_term_list)
    power_list = list(
        map(lambda x: float(x), list(quantity_map_from_settings_api.values()))
    )
    for item in range(len(power_list)):
        if isinstance(term_power_list[item], str) and power_list[item] == 1.0:
            terms.append(term_power_list[item])
        elif isinstance(term_power_list[item], list) and power_list[item] == 1.0:
            for term in term_power_list[item]:
                terms.append(term)
        elif isinstance(term_power_list[item], str) and power_list[item] != 0.0:
            terms.append(
                term_power_list[item]
                + "^"
                + str(
                    int(power_list[item])
                    if power_list[item].is_integer()
                    else power_list[item]
                )
            )
        elif isinstance(term_power_list[item], list) and power_list[item] != 0.0:
            for term in term_power_list[item]:
                if "^" in term:
                    term_split = term.split("^")
                    resulting_power = float(term_split[1]) * power_list[item]
                    terms.append(
                        term_split[0]
                        + "^"
                        + str(
                            int(resulting_power)
                            if resulting_power.is_integer()
                            else resulting_power
                        )
                    )
                else:
                    terms.append(
                        term
                        + "^"
                        + str(
                            int(power_list[item])
                            if power_list[item].is_integer()
                            else power_list[item]
                        )
                    )
    for term in terms:
        final_unit += (" " if len(final_unit) > 0 else "") + term

    unit_term_list = final_unit.split(" ")
    unit_power_list = [
        terms.split("^") if "^" in terms else terms for terms in unit_term_list
    ]

    term_power_map = {}
    for term in unit_power_list:
        if isinstance(term, str):
            if term in term_power_map.keys():
                term_power_map[term] += 1.0
            else:
                term_power_map[term] = 1.0
        if isinstance(term, list):
            if term[0] in term_power_map.keys():
                term_power_map[term[0]] += float(term[1])
            else:
                term_power_map[term[0]] = float(term[1])

    unit_terms = []
    for term, power in term_power_map.items():
        if power == 1.0:
            unit_terms.append(term)
        elif power != 0.0:
            unit_terms.append(
                term + "^" + str(int(power) if power.is_integer() else power)
            )

    unit = ""
    for term in unit_terms:
        unit += (" " if len(unit) > 0 else "") + term
    return unit


class Quantity(float):
    """This class instantiates physical quantities using their real values and
    units.

    Attributes
    ----------
    value: Real value
        Value of quantity is stored as float.

    unit: Unit string
        Unit of quantity is stored as string.

    Methods
    -------
    get_dimensions_list()
        Extracts dimensions from unit.

    is_dimensionless()
        Determines type of quantity.

    to(to_unit)
        Converts to given unit string.

    Returns
    -------
    Quantity instance.

    All the instances of this class are converted to base SI units system to have
    consistency in all arithmetic operations.
    """

    def __init__(self, real_value, unit_str=None, quantity_map=None):
        self._value = float(real_value)
        if unit_str and quantity_map:
            raise ValueError("Either unit or quantity_map is allowed.")
        if quantity_map:
            unit_str = get_unit_from_map(quantity_map)
        self._unit = Unit(unit_str)
        self._dimension = Dimension(unit_str)
        self._si_value = (
            self._unit.si_factor * self._value + self._unit.si_offset
        ) ** self._unit.offset_power
        self._si_unit = self._unit.si_unit
        self._type = self._unit._quantity_type()

    def __new__(cls, real_value, unit_str=None, quantity_map=None):
        if unit_str and quantity_map:
            raise ValueError("Either unit or quantity_map is allowed.")
        if quantity_map:
            unit_str = get_unit_from_map(quantity_map)
        _unit = Unit(unit_str)
        return float.__new__(
            cls, (_unit.si_factor * real_value + _unit.si_offset) ** _unit.offset_power
        )

    @property
    def value(self):
        return self._value

    @property
    def unit(self):
        return self._unit.user_unit

    @value.setter
    def value(self, val):
        self._value = val

    @property
    def dimension(self):
        return self._dimension

    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, type_str):
        self._type = type_str

    def is_dimensionless(self):
        return all([value == 0 for value in self.get_dimensions_list()])

    def get_dimensions_list(self):
        dims = self._dimension.as_dict()
        return [
            dims[_UnitsTable.dimension_order[key]]
            for key in _UnitsTable.dimension_order.keys()
        ]

    def to(self, to_unit_str):
        if not isinstance(to_unit_str, str):
            raise TypeError("Unit should be of 'str' type.")

        temp_quantity = Quantity(1, to_unit_str)

        curr_unit_dim_obj = self.dimension
        to_unit_dim_obj = temp_quantity.dimension

        if curr_unit_dim_obj.as_dict() != to_unit_dim_obj.as_dict():
            raise QuantityError(self.unit, to_unit_str)
        else:
            pass

        if is_temperature_quantity(curr_unit_dim_obj.as_dict()):
            return self._get_converted_temperature(to_unit_str)
        else:
            curr_unit_obj = self._unit
            to_unit_obj = temp_quantity._unit
            temp_quantity.value = (
                curr_unit_obj.si_factor / to_unit_obj.si_factor
            ) * self.value
            return temp_quantity

    def _get_converted_temperature(self, to_unit_str):
        from_unit_str = self.unit

        if "^" in from_unit_str:
            from_unit_str = from_unit_str.split("^")[0]

        if "^" in to_unit_str:
            to_unit_str = to_unit_str.split("^")[0]

        _, prefix = filter_multiplier(
            from_unit_str, lambda item, unit: len(unit) > 0.0 and unit.startswith(item)
        )
        from_unit_multiplier = (
            _UnitsTable.multipliers[prefix] if len(prefix) != 0 else 1.0
        )

        _, prefix = filter_multiplier(
            to_unit_str, lambda item, unit: len(unit) > 0.0 and unit.startswith(item)
        )
        to_unit_multiplier = (
            _UnitsTable.multipliers[prefix] if len(prefix) != 0 else 1.0
        )

        from_key = remove_multiplier(from_unit_str)
        to_key = remove_multiplier(to_unit_str)

        return Quantity(
            _UnitsTable.temperature_conversions[from_key][to_key](
                from_unit_multiplier * self.value
            )
            / to_unit_multiplier,
            to_unit_str,
        )

    def _get_si_unit(self, other, func):
        curr_dim = self.get_dimensions_list()
        other_dim = other.get_dimensions_list()
        temp_dim = [func(curr_dim[i], other_dim[i]) for i in range(len(other_dim))]
        temp_unit = get_si_unit_from_dim(temp_dim)
        return temp_unit

    def __pow__(self, exponent):
        new_dims = list(map(lambda x: x * exponent, self.get_dimensions_list()))
        new_si_unit = get_si_unit_from_dim(new_dims)
        new_si_value = pow(self._si_value, exponent)
        return Quantity(new_si_value, new_si_unit)

    def __str__(self):
        return f'({self.value}, "{self.unit}")'

    def __repr__(self):
        return f'Quantity ({self.value}, "{self.unit}")'

    def __mul__(self, other):
        if isinstance(other, Quantity):
            temp_value = self._si_value * other._si_value
            temp_unit = self._get_si_unit(other, lambda x, y: x + y)
            return Quantity(temp_value, temp_unit)
        elif isinstance(other, int) or isinstance(other, float):
            if self.type == "Temperature Difference":
                result = Quantity(float(self) * float(other), "delta_K")
                result.type = "Temperature Difference"
                return result
            return Quantity(self._si_value * other, self._si_unit)

    def __rmul__(self, other):
        return self.__mul__(other)

    def __truediv__(self, other):
        if isinstance(other, Quantity):
            temp_value = self._si_value / other._si_value
            temp_unit = self._get_si_unit(other, lambda x, y: x - y)
            return Quantity(temp_value, temp_unit)
        elif isinstance(other, int) or isinstance(other, float):
            temp = Quantity(self._si_value / other, self._si_unit)
            return temp

    def __rtruediv__(self, other):
        if not isinstance(other, Quantity) and isinstance(other, float):
            return Quantity(other / self._si_value, self._si_unit)
        else:
            return other / self

    def validate_matching_dimensions(self, other):
        if isinstance(other, Quantity) and (
            self.get_dimensions_list() != other.get_dimensions_list()
        ):
            raise ValueError("Incompatible dimensions.")
        elif (
            (not self.is_dimensionless())
            and (not isinstance(other, Quantity))
            and isinstance(other, (float, int))
        ):
            raise TypeError("Incompatible quantities.")

    def __add__(self, other):
        self.validate_matching_dimensions(other)
        temp_types = ["Temperature", "Temperature Difference"]
        if self.type in temp_types and other.type in temp_types:
            result = Quantity(float(self) + float(other), "K")
            result.type = "Temperature"
            return result
        temp_value = float(self) + float(other)
        return Quantity(temp_value, self._si_unit)

    def __radd__(self, other):
        return Quantity(other, "") + self

    def __sub__(self, other):
        self.validate_matching_dimensions(other)
        temp_types = ["Temperature", "Temperature Difference"]
        if self.type in temp_types and other.type in temp_types:
            result = Quantity(float(self) - float(other), "delta_K")
            result.type = "Temperature Difference"
            return result
        temp_value = float(self) - float(other)
        return Quantity(temp_value, self._si_unit)

    def __rsub__(self, other):
        return Quantity(other, "") - self

    def __neg__(self):
        return Quantity(-self.value, self.unit)

    def __gt__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) > float(other)

    def __ge__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) >= float(other)

    def __lt__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) < float(other)

    def __le__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) <= float(other)

    def __eq__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) == float(other)

    def __neq__(self, other):
        self.validate_matching_dimensions(other)
        return float(self) != float(other)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class tip_loss_limit(Real):
    """
    Set Tip Loss Limit (%R) if using Quadratic tip loss model:.
    """

    fluent_name = "tip-loss-limit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class reorder_partitions_to_architecture(Command):
    """
    Reorder partitions to architecture.
    """

    fluent_name = "reorder-partitions-to-architecture"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .none_1 import none
from .scale_by_global_average import scale_by_global_average
from .scale_by_zone_average import scale_by_zone_average
from .scale_by_global_maximum import scale_by_global_maximum
from .scale_by_zone_maximum import scale_by_zone_maximum
class scaling(Group):
    """
    'scaling' child.
    """

    fluent_name = "scaling"

    child_names = \
        ['option', 'none', 'scale_by_global_average', 'scale_by_zone_average',
         'scale_by_global_maximum', 'scale_by_zone_maximum']

    option: option = option
    """
    option child of scaling.
    """
    none: none = none
    """
    none child of scaling.
    """
    scale_by_global_average: scale_by_global_average = scale_by_global_average
    """
    scale_by_global_average child of scaling.
    """
    scale_by_zone_average: scale_by_zone_average = scale_by_zone_average
    """
    scale_by_zone_average child of scaling.
    """
    scale_by_global_maximum: scale_by_global_maximum = scale_by_global_maximum
    """
    scale_by_global_maximum child of scaling.
    """
    scale_by_zone_maximum: scale_by_zone_maximum = scale_by_zone_maximum
    """
    scale_by_zone_maximum child of scaling.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .basic_info import basic_info
from .disk_origin import disk_origin
from .disk_orientation import disk_orientation
from .disk_id import disk_id
from .blade_pitch_angles import blade_pitch_angles
from .blade_flap_angles import blade_flap_angles
from .tip_loss import tip_loss
class general(Group):
    """
    Menu to define the rotor general information.
    For more details please consult the help option of the corresponding menu or TUI command.
    """

    fluent_name = "general"

    child_names = \
        ['basic_info', 'disk_origin', 'disk_orientation', 'disk_id',
         'blade_pitch_angles', 'blade_flap_angles', 'tip_loss']

    basic_info: basic_info = basic_info
    """
    basic_info child of general.
    """
    disk_origin: disk_origin = disk_origin
    """
    disk_origin child of general.
    """
    disk_orientation: disk_orientation = disk_orientation
    """
    disk_orientation child of general.
    """
    disk_id: disk_id = disk_id
    """
    disk_id child of general.
    """
    blade_pitch_angles: blade_pitch_angles = blade_pitch_angles
    """
    blade_pitch_angles child of general.
    """
    blade_flap_angles: blade_flap_angles = blade_flap_angles
    """
    blade_flap_angles child of general.
    """
    tip_loss: tip_loss = tip_loss
    """
    tip_loss child of general.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .verbosity_3 import verbosity
class options(Group):
    """
    'options' child.
    """

    fluent_name = "options"

    child_names = \
        ['verbosity']

    verbosity: verbosity = verbosity
    """
    verbosity child of options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .nist_fluid import nist_fluid
from .lookup_table import lookup_table
from .pressure_points import pressure_points
from .pressure_minimum import pressure_minimum
from .pressure_maximum import pressure_maximum
from .temperature_points import temperature_points
from .temperature_minimum import temperature_minimum
from .temperature_maximum import temperature_maximum
from .saturation_points import saturation_points
class real_gas_nist(Group):
    """
    'real_gas_nist' child.
    """

    fluent_name = "real-gas-nist"

    child_names = \
        ['nist_fluid', 'lookup_table', 'pressure_points', 'pressure_minimum',
         'pressure_maximum', 'temperature_points', 'temperature_minimum',
         'temperature_maximum', 'saturation_points']

    nist_fluid: nist_fluid = nist_fluid
    """
    nist_fluid child of real_gas_nist.
    """
    lookup_table: lookup_table = lookup_table
    """
    lookup_table child of real_gas_nist.
    """
    pressure_points: pressure_points = pressure_points
    """
    pressure_points child of real_gas_nist.
    """
    pressure_minimum: pressure_minimum = pressure_minimum
    """
    pressure_minimum child of real_gas_nist.
    """
    pressure_maximum: pressure_maximum = pressure_maximum
    """
    pressure_maximum child of real_gas_nist.
    """
    temperature_points: temperature_points = temperature_points
    """
    temperature_points child of real_gas_nist.
    """
    temperature_minimum: temperature_minimum = temperature_minimum
    """
    temperature_minimum child of real_gas_nist.
    """
    temperature_maximum: temperature_maximum = temperature_maximum
    """
    temperature_maximum child of real_gas_nist.
    """
    saturation_points: saturation_points = saturation_points
    """
    saturation_points child of real_gas_nist.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .cross_section_multicomponent_child import cross_section_multicomponent_child

class cross_section_multicomponent(NamedObject[cross_section_multicomponent_child], _NonCreatableNamedObjectMixin[cross_section_multicomponent_child]):
    """
    'cross_section_multicomponent' child.
    """

    fluent_name = "cross-section-multicomponent"

    child_object_type: cross_section_multicomponent_child = cross_section_multicomponent_child
    """
    child_object_type of cross_section_multicomponent.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .subgrid_scale_turb_visc import subgrid_scale_turb_visc
from .turb_visc_func_mf import turb_visc_func_mf
from .turb_visc_func import turb_visc_func
from .tke_prandtl import tke_prandtl
from .tdr_prandtl import tdr_prandtl
from .sdr_prandtl import sdr_prandtl
from .energy_prandtl import energy_prandtl
from .wall_prandtl import wall_prandtl
from .turbulent_schmidt import turbulent_schmidt
class user_defined(Group):
    """
    'user_defined' child.
    """

    fluent_name = "user-defined"

    child_names = \
        ['subgrid_scale_turb_visc', 'turb_visc_func_mf', 'turb_visc_func',
         'tke_prandtl', 'tdr_prandtl', 'sdr_prandtl', 'energy_prandtl',
         'wall_prandtl', 'turbulent_schmidt']

    subgrid_scale_turb_visc: subgrid_scale_turb_visc = subgrid_scale_turb_visc
    """
    subgrid_scale_turb_visc child of user_defined.
    """
    turb_visc_func_mf: turb_visc_func_mf = turb_visc_func_mf
    """
    turb_visc_func_mf child of user_defined.
    """
    turb_visc_func: turb_visc_func = turb_visc_func
    """
    turb_visc_func child of user_defined.
    """
    tke_prandtl: tke_prandtl = tke_prandtl
    """
    tke_prandtl child of user_defined.
    """
    tdr_prandtl: tdr_prandtl = tdr_prandtl
    """
    tdr_prandtl child of user_defined.
    """
    sdr_prandtl: sdr_prandtl = sdr_prandtl
    """
    sdr_prandtl child of user_defined.
    """
    energy_prandtl: energy_prandtl = energy_prandtl
    """
    energy_prandtl child of user_defined.
    """
    wall_prandtl: wall_prandtl = wall_prandtl
    """
    wall_prandtl child of user_defined.
    """
    turbulent_schmidt: turbulent_schmidt = turbulent_schmidt
    """
    turbulent_schmidt child of user_defined.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .vibrational_temperature_mode_1 import vibrational_temperature_mode_1
from .vibrational_degeneracy_mode_1 import vibrational_degeneracy_mode_1
from .vibrational_temperature_mode_2 import vibrational_temperature_mode_2
from .vibrational_degeneracy_mode_2 import vibrational_degeneracy_mode_2
from .vibrational_temperature_mode_3 import vibrational_temperature_mode_3
from .vibrational_degeneracy_mode_3 import vibrational_degeneracy_mode_3
class vibrational_modes(Group):
    """
    'vibrational_modes' child.
    """

    fluent_name = "vibrational-modes"

    child_names = \
        ['vibrational_temperature_mode_1', 'vibrational_degeneracy_mode_1',
         'vibrational_temperature_mode_2', 'vibrational_degeneracy_mode_2',
         'vibrational_temperature_mode_3', 'vibrational_degeneracy_mode_3']

    vibrational_temperature_mode_1: vibrational_temperature_mode_1 = vibrational_temperature_mode_1
    """
    vibrational_temperature_mode_1 child of vibrational_modes.
    """
    vibrational_degeneracy_mode_1: vibrational_degeneracy_mode_1 = vibrational_degeneracy_mode_1
    """
    vibrational_degeneracy_mode_1 child of vibrational_modes.
    """
    vibrational_temperature_mode_2: vibrational_temperature_mode_2 = vibrational_temperature_mode_2
    """
    vibrational_temperature_mode_2 child of vibrational_modes.
    """
    vibrational_degeneracy_mode_2: vibrational_degeneracy_mode_2 = vibrational_degeneracy_mode_2
    """
    vibrational_degeneracy_mode_2 child of vibrational_modes.
    """
    vibrational_temperature_mode_3: vibrational_temperature_mode_3 = vibrational_temperature_mode_3
    """
    vibrational_temperature_mode_3 child of vibrational_modes.
    """
    vibrational_degeneracy_mode_3: vibrational_degeneracy_mode_3 = vibrational_degeneracy_mode_3
    """
    vibrational_degeneracy_mode_3 child of vibrational_modes.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_9 import option
from .compressible_liquid import compressible_liquid
from .user_defined_function import user_defined_function
from .value import value
class density(Group):
    """
    'density' child.
    """

    fluent_name = "density"

    child_names = \
        ['option', 'compressible_liquid', 'user_defined_function', 'value']

    option: option = option
    """
    option child of density.
    """
    compressible_liquid: compressible_liquid = compressible_liquid
    """
    compressible_liquid child of density.
    """
    user_defined_function: user_defined_function = user_defined_function
    """
    user_defined_function child of density.
    """
    value: value = value
    """
    value child of density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .display import display
from .mesh_child_1 import mesh_child

class mesh(NamedObject[mesh_child], _CreatableNamedObjectMixin[mesh_child]):
    """
    'mesh' child.
    """

    fluent_name = "mesh"

    command_names = \
        ['display']

    display: display = display
    """
    display command of mesh.
    """
    child_object_type: mesh_child = mesh_child
    """
    child_object_type of mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class render_mesh(Boolean):
    """
    Determine whether or not to render the mesh on top of contours, vectors, etc.
    """

    fluent_name = "render-mesh?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_21 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .pid import pid
from .temperature_spec import temperature_spec
from .temperature_rise import temperature_rise
from .heat_source import heat_source
from .tinf import tinf
from .hc import hc
from .direction_spec import direction_spec
from .coordinate_system import coordinate_system
from .flow_direction import flow_direction
from .direction_vector import direction_vector
from .ke_spec import ke_spec
from .nut import nut
from .kl import kl
from .intermit import intermit
from .k import k
from .e import e
from .o import o
from .v2 import v2
from .turb_intensity import turb_intensity
from .turb_length_scale import turb_length_scale
from .turb_hydraulic_diam import turb_hydraulic_diam
from .turb_viscosity_ratio import turb_viscosity_ratio
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile
from .rst_spec import rst_spec
from .uu import uu
from .vv import vv
from .ww import ww
from .uv import uv
from .vw import vw
from .uw import uw
from .ksgs_spec import ksgs_spec
from .ksgs import ksgs
from .sgs_turb_intensity import sgs_turb_intensity
from .mass_flow_multiplier import mass_flow_multiplier
from .solar_fluxes import solar_fluxes
from .solar_shining_factor import solar_shining_factor
class recirculation_inlet_child(Group):
    """
    'child_object_type' of recirculation_inlet.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'pid',
         'temperature_spec', 'temperature_rise', 'heat_source', 'tinf', 'hc',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'direction_vector', 'ke_spec', 'nut', 'kl', 'intermit', 'k', 'e',
         'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'mass_flow_multiplier', 'solar_fluxes', 'solar_shining_factor']

    phase: phase = phase
    """
    phase child of recirculation_inlet_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of recirculation_inlet_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of recirculation_inlet_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of recirculation_inlet_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of recirculation_inlet_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of recirculation_inlet_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of recirculation_inlet_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of recirculation_inlet_child.
    """
    pid: pid = pid
    """
    pid child of recirculation_inlet_child.
    """
    temperature_spec: temperature_spec = temperature_spec
    """
    temperature_spec child of recirculation_inlet_child.
    """
    temperature_rise: temperature_rise = temperature_rise
    """
    temperature_rise child of recirculation_inlet_child.
    """
    heat_source: heat_source = heat_source
    """
    heat_source child of recirculation_inlet_child.
    """
    tinf: tinf = tinf
    """
    tinf child of recirculation_inlet_child.
    """
    hc: hc = hc
    """
    hc child of recirculation_inlet_child.
    """
    direction_spec: direction_spec = direction_spec
    """
    direction_spec child of recirculation_inlet_child.
    """
    coordinate_system: coordinate_system = coordinate_system
    """
    coordinate_system child of recirculation_inlet_child.
    """
    flow_direction: flow_direction = flow_direction
    """
    flow_direction child of recirculation_inlet_child.
    """
    direction_vector: direction_vector = direction_vector
    """
    direction_vector child of recirculation_inlet_child.
    """
    ke_spec: ke_spec = ke_spec
    """
    ke_spec child of recirculation_inlet_child.
    """
    nut: nut = nut
    """
    nut child of recirculation_inlet_child.
    """
    kl: kl = kl
    """
    kl child of recirculation_inlet_child.
    """
    intermit: intermit = intermit
    """
    intermit child of recirculation_inlet_child.
    """
    k: k = k
    """
    k child of recirculation_inlet_child.
    """
    e: e = e
    """
    e child of recirculation_inlet_child.
    """
    o: o = o
    """
    o child of recirculation_inlet_child.
    """
    v2: v2 = v2
    """
    v2 child of recirculation_inlet_child.
    """
    turb_intensity: turb_intensity = turb_intensity
    """
    turb_intensity child of recirculation_inlet_child.
    """
    turb_length_scale: turb_length_scale = turb_length_scale
    """
    turb_length_scale child of recirculation_inlet_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam = turb_hydraulic_diam
    """
    turb_hydraulic_diam child of recirculation_inlet_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio = turb_viscosity_ratio
    """
    turb_viscosity_ratio child of recirculation_inlet_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile = turb_viscosity_ratio_profile
    """
    turb_viscosity_ratio_profile child of recirculation_inlet_child.
    """
    rst_spec: rst_spec = rst_spec
    """
    rst_spec child of recirculation_inlet_child.
    """
    uu: uu = uu
    """
    uu child of recirculation_inlet_child.
    """
    vv: vv = vv
    """
    vv child of recirculation_inlet_child.
    """
    ww: ww = ww
    """
    ww child of recirculation_inlet_child.
    """
    uv: uv = uv
    """
    uv child of recirculation_inlet_child.
    """
    vw: vw = vw
    """
    vw child of recirculation_inlet_child.
    """
    uw: uw = uw
    """
    uw child of recirculation_inlet_child.
    """
    ksgs_spec: ksgs_spec = ksgs_spec
    """
    ksgs_spec child of recirculation_inlet_child.
    """
    ksgs: ksgs = ksgs
    """
    ksgs child of recirculation_inlet_child.
    """
    sgs_turb_intensity: sgs_turb_intensity = sgs_turb_intensity
    """
    sgs_turb_intensity child of recirculation_inlet_child.
    """
    mass_flow_multiplier: mass_flow_multiplier = mass_flow_multiplier
    """
    mass_flow_multiplier child of recirculation_inlet_child.
    """
    solar_fluxes: solar_fluxes = solar_fluxes
    """
    solar_fluxes child of recirculation_inlet_child.
    """
    solar_shining_factor: solar_shining_factor = solar_shining_factor
    """
    solar_shining_factor child of recirculation_inlet_child.
    """



_CODEGEN_MSG_DATAMODEL = (
    "Currently calling the datamodel API in a generic manner. "
    "Please run `python codegen/allapigen.py` from the top-level pyfluent "
    "directory to generate the local datamodel API classes."
)

_CODEGEN_MSG_TUI = (
    "Currently calling the TUI commands in a generic manner. "
    "Please run `python codegen/allapigen.py` from the top-level pyfluent "
    "directory to generate the local TUI commands classes."
)



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .geometry_3 import geometry
from .physics import physics
from .retain_instantaneous_values import retain_instantaneous_values
from .phase_25 import phase
from .average_over import average_over
from .per_zone import per_zone
from .old_props import old_props
from .zone_names import zone_names
from .zone_ids import zone_ids
class flux_child(Group):
    """
    'child_object_type' of flux.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['report_type', 'geometry', 'physics', 'retain_instantaneous_values',
         'phase', 'average_over', 'per_zone', 'old_props', 'zone_names',
         'zone_ids']

    report_type: report_type = report_type
    """
    report_type child of flux_child.
    """
    geometry: geometry = geometry
    """
    geometry child of flux_child.
    """
    physics: physics = physics
    """
    physics child of flux_child.
    """
    retain_instantaneous_values: retain_instantaneous_values = retain_instantaneous_values
    """
    retain_instantaneous_values child of flux_child.
    """
    phase: phase = phase
    """
    phase child of flux_child.
    """
    average_over: average_over = average_over
    """
    average_over child of flux_child.
    """
    per_zone: per_zone = per_zone
    """
    per_zone child of flux_child.
    """
    old_props: old_props = old_props
    """
    old_props child of flux_child.
    """
    zone_names: zone_names = zone_names
    """
    zone_names child of flux_child.
    """
    zone_ids: zone_ids = zone_ids
    """
    zone_ids child of flux_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .report_type import report_type
from .disc_output_type import disc_output_type
from .qmom_output_type import qmom_output_type
from .smm_output_type import smm_output_type
from .surface_list import surface_list
from .volume_list import volume_list
from .num_dens_func import num_dens_func
from .dia_upper_limit import dia_upper_limit
from .file_name_1 import file_name
from .overwrite import overwrite
class number_density(Command):
    """
    'number_density' command.
    
    Parameters
    ----------
        report_type : str
            'report_type' child.
        disc_output_type : str
            'disc_output_type' child.
        qmom_output_type : str
            'qmom_output_type' child.
        smm_output_type : str
            'smm_output_type' child.
        surface_list : typing.List[str]
            'surface_list' child.
        volume_list : typing.List[str]
            'volume_list' child.
        num_dens_func : str
            'num_dens_func' child.
        dia_upper_limit : real
            'dia_upper_limit' child.
        file_name : str
            'file_name' child.
        overwrite : bool
            'overwrite' child.
    
    """

    fluent_name = "number-density"

    argument_names = \
        ['report_type', 'disc_output_type', 'qmom_output_type',
         'smm_output_type', 'surface_list', 'volume_list', 'num_dens_func',
         'dia_upper_limit', 'file_name', 'overwrite']

    report_type: report_type = report_type
    """
    report_type argument of number_density.
    """
    disc_output_type: disc_output_type = disc_output_type
    """
    disc_output_type argument of number_density.
    """
    qmom_output_type: qmom_output_type = qmom_output_type
    """
    qmom_output_type argument of number_density.
    """
    smm_output_type: smm_output_type = smm_output_type
    """
    smm_output_type argument of number_density.
    """
    surface_list: surface_list = surface_list
    """
    surface_list argument of number_density.
    """
    volume_list: volume_list = volume_list
    """
    volume_list argument of number_density.
    """
    num_dens_func: num_dens_func = num_dens_func
    """
    num_dens_func argument of number_density.
    """
    dia_upper_limit: dia_upper_limit = dia_upper_limit
    """
    dia_upper_limit argument of number_density.
    """
    file_name: file_name = file_name
    """
    file_name argument of number_density.
    """
    overwrite: overwrite = overwrite
    """
    overwrite argument of number_density.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .max_fine_relaxations import max_fine_relaxations
from .max_coarse_relaxations import max_coarse_relaxations
class flexible_cycle_parameters(Group):
    """
    'flexible_cycle_parameters' child.
    """

    fluent_name = "flexible-cycle-parameters"

    child_names = \
        ['max_fine_relaxations', 'max_coarse_relaxations']

    max_fine_relaxations: max_fine_relaxations = max_fine_relaxations
    """
    max_fine_relaxations child of flexible_cycle_parameters.
    """
    max_coarse_relaxations: max_coarse_relaxations = max_coarse_relaxations
    """
    max_coarse_relaxations child of flexible_cycle_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_8 import phase
from .is_not_a_rans_les_interface import is_not_a_rans_les_interface
class interior_child(Group):
    """
    'child_object_type' of interior.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'is_not_a_rans_les_interface']

    phase: phase = phase
    """
    phase child of interior_child.
    """
    is_not_a_rans_les_interface: is_not_a_rans_les_interface = is_not_a_rans_les_interface
    """
    is_not_a_rans_les_interface child of interior_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .format_name import format_name
class write_animation(Command):
    """
    Write animation sequence to the file.
    
    Parameters
    ----------
        format_name : str
            'format_name' child.
    
    """

    fluent_name = "write-animation"

    argument_names = \
        ['format_name']

    format_name: format_name = format_name
    """
    format_name argument of write_animation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .phase_14 import phase
from .geom_disable import geom_disable
from .geom_dir_spec import geom_dir_spec
from .geom_dir_x import geom_dir_x
from .geom_dir_y import geom_dir_y
from .geom_dir_z import geom_dir_z
from .geom_levels import geom_levels
from .geom_bgthread import geom_bgthread
from .angular import angular
from .p_jump import p_jump
class periodic_child(Group):
    """
    'child_object_type' of periodic.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'angular', 'p_jump']

    phase: phase = phase
    """
    phase child of periodic_child.
    """
    geom_disable: geom_disable = geom_disable
    """
    geom_disable child of periodic_child.
    """
    geom_dir_spec: geom_dir_spec = geom_dir_spec
    """
    geom_dir_spec child of periodic_child.
    """
    geom_dir_x: geom_dir_x = geom_dir_x
    """
    geom_dir_x child of periodic_child.
    """
    geom_dir_y: geom_dir_y = geom_dir_y
    """
    geom_dir_y child of periodic_child.
    """
    geom_dir_z: geom_dir_z = geom_dir_z
    """
    geom_dir_z child of periodic_child.
    """
    geom_levels: geom_levels = geom_levels
    """
    geom_levels child of periodic_child.
    """
    geom_bgthread: geom_bgthread = geom_bgthread
    """
    geom_bgthread child of periodic_child.
    """
    angular: angular = angular
    """
    angular child of periodic_child.
    """
    p_jump: p_jump = p_jump
    """
    p_jump child of periodic_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_4 import enable
from .mode import mode
from .disk import disk
from .list_disk_names import list_disk_names
class virtual_blade_model(Group):
    """
    Enter the vbm model menu.
    """

    fluent_name = "virtual-blade-model"

    child_names = \
        ['enable', 'mode', 'disk']

    enable: enable = enable
    """
    enable child of virtual_blade_model.
    """
    mode: mode = mode
    """
    mode child of virtual_blade_model.
    """
    disk: disk = disk
    """
    disk child of virtual_blade_model.
    """
    command_names = \
        ['list_disk_names']

    list_disk_names: list_disk_names = list_disk_names
    """
    list_disk_names command of virtual_blade_model.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .const_htc import const_htc
from .const_nu import const_nu
class heat_transfer(Group):
    """
    'heat_transfer' child.
    """

    fluent_name = "heat-transfer"

    child_names = \
        ['option', 'const_htc', 'const_nu']

    option: option = option
    """
    option child of heat_transfer.
    """
    const_htc: const_htc = const_htc
    """
    const_htc child of heat_transfer.
    """
    const_nu: const_nu = const_nu
    """
    const_nu child of heat_transfer.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled_2 import enabled
from .turbulent_intensity import turbulent_intensity
from .turbulent_viscosity_ratio import turbulent_viscosity_ratio
class localized_turb_init(Group):
    """
    Localized initialization of turbulent flow variables for VOF/Mixture multiphase flow models.
    """

    fluent_name = "localized-turb-init"

    child_names = \
        ['enabled', 'turbulent_intensity', 'turbulent_viscosity_ratio']

    enabled: enabled = enabled
    """
    enabled child of localized_turb_init.
    """
    turbulent_intensity: turbulent_intensity = turbulent_intensity
    """
    turbulent_intensity child of localized_turb_init.
    """
    turbulent_viscosity_ratio: turbulent_viscosity_ratio = turbulent_viscosity_ratio
    """
    turbulent_viscosity_ratio child of localized_turb_init.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .ap_face_zone import ap_face_zone
from .beam_length import beam_length
from .ray_points_count import ray_points_count
from .beam_vector import beam_vector
class beams_child(Group):
    """
    'child_object_type' of beams.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['ap_face_zone', 'beam_length', 'ray_points_count', 'beam_vector']

    ap_face_zone: ap_face_zone = ap_face_zone
    """
    ap_face_zone child of beams_child.
    """
    beam_length: beam_length = beam_length
    """
    beam_length child of beams_child.
    """
    ray_points_count: ray_points_count = ray_points_count
    """
    ray_points_count child of beams_child.
    """
    beam_vector: beam_vector = beam_vector
    """
    beam_vector child of beams_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enabled import enabled
from .viscous_dissipation import viscous_dissipation
from .pressure_work import pressure_work
from .kinetic_energy import kinetic_energy
from .inlet_diffusion import inlet_diffusion
class energy(Group):
    """
    Enter the energy transport model settings.
    """

    fluent_name = "energy"

    child_names = \
        ['enabled', 'viscous_dissipation', 'pressure_work', 'kinetic_energy',
         'inlet_diffusion']

    enabled: enabled = enabled
    """
    enabled child of energy.
    """
    viscous_dissipation: viscous_dissipation = viscous_dissipation
    """
    viscous_dissipation child of energy.
    """
    pressure_work: pressure_work = pressure_work
    """
    pressure_work child of energy.
    """
    kinetic_energy: kinetic_energy = kinetic_energy
    """
    kinetic_energy child of energy.
    """
    inlet_diffusion: inlet_diffusion = inlet_diffusion
    """
    inlet_diffusion child of energy.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .field import field
from .scalefactor import scalefactor
class ribbon(Group):
    """
    'ribbon' child.
    """

    fluent_name = "ribbon"

    child_names = \
        ['field', 'scalefactor']

    field: field = field
    """
    field child of ribbon.
    """
    scalefactor: scalefactor = scalefactor
    """
    scalefactor child of ribbon.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .enable_9 import enable
from .disable_1 import disable
from .copy_2 import copy
from .delete_1 import delete
from .export_1 import export
from .import__1 import import_
class execute_commands(Group):
    """
    'execute_commands' child.
    """

    fluent_name = "execute-commands"

    command_names = \
        ['enable', 'disable', 'copy', 'delete', 'export', 'import_']

    enable: enable = enable
    """
    enable command of execute_commands.
    """
    disable: disable = disable
    """
    disable command of execute_commands.
    """
    copy: copy = copy
    """
    copy command of execute_commands.
    """
    delete: delete = delete
    """
    delete command of execute_commands.
    """
    export: export = export
    """
    export command of execute_commands.
    """
    import_: import_ = import_
    """
    import_ command of execute_commands.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .xyz import xyz
class target(Command):
    """
    Set the point to be the center of the camera view.
    
    Parameters
    ----------
        xyz : typing.List[real]
            'xyz' child.
    
    """

    fluent_name = "target"

    argument_names = \
        ['xyz']

    xyz: xyz = xyz
    """
    xyz argument of target.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .axis_child import axis_child

class degassing(NamedObject[axis_child], _NonCreatableNamedObjectMixin[axis_child]):
    """
    'degassing' child.
    """

    fluent_name = "degassing"

    child_object_type: axis_child = axis_child
    """
    child_object_type of degassing.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .density_2 import density
from .viscosity_1 import viscosity
from .specific_heat_2 import specific_heat
from .thermal_conductivity_2 import thermal_conductivity
from .premix_laminar_speed import premix_laminar_speed
from .premix_laminar_thickness import premix_laminar_thickness
from .premix_unburnt_temp_1 import premix_unburnt_temp
from .premix_unburnt_cp import premix_unburnt_cp
from .premix_unburnt_density_1 import premix_unburnt_density
from .premix_heat_trans_coeff_1 import premix_heat_trans_coeff
from .premix_critical_strain import premix_critical_strain
from .therm_exp_coeff import therm_exp_coeff
from .absorption_coefficient_1 import absorption_coefficient
from .scattering_coefficient import scattering_coefficient
from .scattering_phase_function import scattering_phase_function
from .refractive_index import refractive_index
from .mass_diffusivity_1 import mass_diffusivity
from .species import species
from .reactions import reactions
from .reaction_mechs import reaction_mechs
from .uds_diffusivity import uds_diffusivity
from .thermal_diffusivity import thermal_diffusivity
from .tmelt import tmelt
from .melting_heat import melting_heat
from .eutectic_temp import eutectic_temp
from .speed_of_sound import speed_of_sound
from .critical_temperature import critical_temperature
from .critical_pressure import critical_pressure
from .critical_volume import critical_volume
from .acentric_factor import acentric_factor
from .electric_conductivity import electric_conductivity
from .dual_electric_conductivity import dual_electric_conductivity
from .lithium_diffusivity import lithium_diffusivity
from .collision_cross_section import collision_cross_section
from .mixture_species import mixture_species
class mixture_child(Group):
    """
    'child_object_type' of mixture.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['density', 'viscosity', 'specific_heat', 'thermal_conductivity',
         'premix_laminar_speed', 'premix_laminar_thickness',
         'premix_unburnt_temp', 'premix_unburnt_cp', 'premix_unburnt_density',
         'premix_heat_trans_coeff', 'premix_critical_strain',
         'therm_exp_coeff', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'refractive_index', 'mass_diffusivity', 'species', 'reactions',
         'reaction_mechs', 'uds_diffusivity', 'thermal_diffusivity', 'tmelt',
         'melting_heat', 'eutectic_temp', 'speed_of_sound',
         'critical_temperature', 'critical_pressure', 'critical_volume',
         'acentric_factor', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'collision_cross_section', 'mixture_species']

    density: density = density
    """
    density child of mixture_child.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of mixture_child.
    """
    specific_heat: specific_heat = specific_heat
    """
    specific_heat child of mixture_child.
    """
    thermal_conductivity: thermal_conductivity = thermal_conductivity
    """
    thermal_conductivity child of mixture_child.
    """
    premix_laminar_speed: premix_laminar_speed = premix_laminar_speed
    """
    premix_laminar_speed child of mixture_child.
    """
    premix_laminar_thickness: premix_laminar_thickness = premix_laminar_thickness
    """
    premix_laminar_thickness child of mixture_child.
    """
    premix_unburnt_temp: premix_unburnt_temp = premix_unburnt_temp
    """
    premix_unburnt_temp child of mixture_child.
    """
    premix_unburnt_cp: premix_unburnt_cp = premix_unburnt_cp
    """
    premix_unburnt_cp child of mixture_child.
    """
    premix_unburnt_density: premix_unburnt_density = premix_unburnt_density
    """
    premix_unburnt_density child of mixture_child.
    """
    premix_heat_trans_coeff: premix_heat_trans_coeff = premix_heat_trans_coeff
    """
    premix_heat_trans_coeff child of mixture_child.
    """
    premix_critical_strain: premix_critical_strain = premix_critical_strain
    """
    premix_critical_strain child of mixture_child.
    """
    therm_exp_coeff: therm_exp_coeff = therm_exp_coeff
    """
    therm_exp_coeff child of mixture_child.
    """
    absorption_coefficient: absorption_coefficient = absorption_coefficient
    """
    absorption_coefficient child of mixture_child.
    """
    scattering_coefficient: scattering_coefficient = scattering_coefficient
    """
    scattering_coefficient child of mixture_child.
    """
    scattering_phase_function: scattering_phase_function = scattering_phase_function
    """
    scattering_phase_function child of mixture_child.
    """
    refractive_index: refractive_index = refractive_index
    """
    refractive_index child of mixture_child.
    """
    mass_diffusivity: mass_diffusivity = mass_diffusivity
    """
    mass_diffusivity child of mixture_child.
    """
    species: species = species
    """
    species child of mixture_child.
    """
    reactions: reactions = reactions
    """
    reactions child of mixture_child.
    """
    reaction_mechs: reaction_mechs = reaction_mechs
    """
    reaction_mechs child of mixture_child.
    """
    uds_diffusivity: uds_diffusivity = uds_diffusivity
    """
    uds_diffusivity child of mixture_child.
    """
    thermal_diffusivity: thermal_diffusivity = thermal_diffusivity
    """
    thermal_diffusivity child of mixture_child.
    """
    tmelt: tmelt = tmelt
    """
    tmelt child of mixture_child.
    """
    melting_heat: melting_heat = melting_heat
    """
    melting_heat child of mixture_child.
    """
    eutectic_temp: eutectic_temp = eutectic_temp
    """
    eutectic_temp child of mixture_child.
    """
    speed_of_sound: speed_of_sound = speed_of_sound
    """
    speed_of_sound child of mixture_child.
    """
    critical_temperature: critical_temperature = critical_temperature
    """
    critical_temperature child of mixture_child.
    """
    critical_pressure: critical_pressure = critical_pressure
    """
    critical_pressure child of mixture_child.
    """
    critical_volume: critical_volume = critical_volume
    """
    critical_volume child of mixture_child.
    """
    acentric_factor: acentric_factor = acentric_factor
    """
    acentric_factor child of mixture_child.
    """
    electric_conductivity: electric_conductivity = electric_conductivity
    """
    electric_conductivity child of mixture_child.
    """
    dual_electric_conductivity: dual_electric_conductivity = dual_electric_conductivity
    """
    dual_electric_conductivity child of mixture_child.
    """
    lithium_diffusivity: lithium_diffusivity = lithium_diffusivity
    """
    lithium_diffusivity child of mixture_child.
    """
    collision_cross_section: collision_cross_section = collision_cross_section
    """
    collision_cross_section child of mixture_child.
    """
    mixture_species: mixture_species = mixture_species
    """
    mixture_species child of mixture_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .list_simulation_reports import list_simulation_reports
from .generate_simulation_report import generate_simulation_report
from .view_simulation_report import view_simulation_report
from .export_simulation_report_as_pdf import export_simulation_report_as_pdf
from .export_simulation_report_as_html import export_simulation_report_as_html
from .export_simulation_report_as_pptx import export_simulation_report_as_pptx
from .write_simulation_report_names_to_file import write_simulation_report_names_to_file
from .rename_simulation_report import rename_simulation_report
from .duplicate_simulation_report import duplicate_simulation_report
from .reset_report_to_defaults import reset_report_to_defaults
from .delete_simulation_report import delete_simulation_report
from .write_simulation_report_template_file import write_simulation_report_template_file
from .read_simulation_report_template_file import read_simulation_report_template_file
class simulation_reports(Group):
    """
    'simulation_reports' child.
    """

    fluent_name = "simulation-reports"

    command_names = \
        ['list_simulation_reports', 'generate_simulation_report',
         'view_simulation_report', 'export_simulation_report_as_pdf',
         'export_simulation_report_as_html',
         'export_simulation_report_as_pptx',
         'write_simulation_report_names_to_file', 'rename_simulation_report',
         'duplicate_simulation_report', 'reset_report_to_defaults',
         'delete_simulation_report', 'write_simulation_report_template_file',
         'read_simulation_report_template_file']

    list_simulation_reports: list_simulation_reports = list_simulation_reports
    """
    list_simulation_reports command of simulation_reports.
    """
    generate_simulation_report: generate_simulation_report = generate_simulation_report
    """
    generate_simulation_report command of simulation_reports.
    """
    view_simulation_report: view_simulation_report = view_simulation_report
    """
    view_simulation_report command of simulation_reports.
    """
    export_simulation_report_as_pdf: export_simulation_report_as_pdf = export_simulation_report_as_pdf
    """
    export_simulation_report_as_pdf command of simulation_reports.
    """
    export_simulation_report_as_html: export_simulation_report_as_html = export_simulation_report_as_html
    """
    export_simulation_report_as_html command of simulation_reports.
    """
    export_simulation_report_as_pptx: export_simulation_report_as_pptx = export_simulation_report_as_pptx
    """
    export_simulation_report_as_pptx command of simulation_reports.
    """
    write_simulation_report_names_to_file: write_simulation_report_names_to_file = write_simulation_report_names_to_file
    """
    write_simulation_report_names_to_file command of simulation_reports.
    """
    rename_simulation_report: rename_simulation_report = rename_simulation_report
    """
    rename_simulation_report command of simulation_reports.
    """
    duplicate_simulation_report: duplicate_simulation_report = duplicate_simulation_report
    """
    duplicate_simulation_report command of simulation_reports.
    """
    reset_report_to_defaults: reset_report_to_defaults = reset_report_to_defaults
    """
    reset_report_to_defaults command of simulation_reports.
    """
    delete_simulation_report: delete_simulation_report = delete_simulation_report
    """
    delete_simulation_report command of simulation_reports.
    """
    write_simulation_report_template_file: write_simulation_report_template_file = write_simulation_report_template_file
    """
    write_simulation_report_template_file command of simulation_reports.
    """
    read_simulation_report_template_file: read_simulation_report_template_file = read_simulation_report_template_file
    """
    read_simulation_report_template_file command of simulation_reports.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .transient_parameters_specify import transient_parameters_specify
from .transient_scheme import transient_scheme
from .time_scale_modification_method import time_scale_modification_method
from .time_scale_modification_factor import time_scale_modification_factor
class transient(Group):
    """
    'transient' child.
    """

    fluent_name = "transient"

    child_names = \
        ['transient_parameters_specify', 'transient_scheme',
         'time_scale_modification_method', 'time_scale_modification_factor']

    transient_parameters_specify: transient_parameters_specify = transient_parameters_specify
    """
    transient_parameters_specify child of transient.
    """
    transient_scheme: transient_scheme = transient_scheme
    """
    transient_scheme child of transient.
    """
    time_scale_modification_method: time_scale_modification_method = time_scale_modification_method
    """
    time_scale_modification_method child of transient.
    """
    time_scale_modification_factor: time_scale_modification_factor = time_scale_modification_factor
    """
    time_scale_modification_factor child of transient.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .point_surface import point_surface
from .plane_surface import plane_surface
class surfaces(Group):
    """
    'surfaces' child.
    """

    fluent_name = "surfaces"

    child_names = \
        ['point_surface', 'plane_surface']

    point_surface: point_surface = point_surface
    """
    point_surface child of surfaces.
    """
    plane_surface: plane_surface = plane_surface
    """
    plane_surface child of surfaces.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .vof_from_min_limit import vof_from_min_limit
from .vof_from_max_limit import vof_from_max_limit
from .vof_to_min_limit import vof_to_min_limit
from .vof_to_max_limit import vof_to_max_limit
from .ia_norm_min_limit import ia_norm_min_limit
from .max_rel_humidity import max_rel_humidity
class evaporation_condensation(Group):
    """
    'evaporation_condensation' child.
    """

    fluent_name = "evaporation-condensation"

    child_names = \
        ['vof_from_min_limit', 'vof_from_max_limit', 'vof_to_min_limit',
         'vof_to_max_limit', 'ia_norm_min_limit', 'max_rel_humidity']

    vof_from_min_limit: vof_from_min_limit = vof_from_min_limit
    """
    vof_from_min_limit child of evaporation_condensation.
    """
    vof_from_max_limit: vof_from_max_limit = vof_from_max_limit
    """
    vof_from_max_limit child of evaporation_condensation.
    """
    vof_to_min_limit: vof_to_min_limit = vof_to_min_limit
    """
    vof_to_min_limit child of evaporation_condensation.
    """
    vof_to_max_limit: vof_to_max_limit = vof_to_max_limit
    """
    vof_to_max_limit child of evaporation_condensation.
    """
    ia_norm_min_limit: ia_norm_min_limit = ia_norm_min_limit
    """
    ia_norm_min_limit child of evaporation_condensation.
    """
    max_rel_humidity: max_rel_humidity = max_rel_humidity
    """
    max_rel_humidity child of evaporation_condensation.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .models import models
from .vaporization_pressure import vaporization_pressure
from .non_condensable_gas import non_condensable_gas
from .liquid_surface_tension import liquid_surface_tension
from .bubble_number_density import bubble_number_density
from .number_of_phases import number_of_phases
from .number_of_eulerian_discrete_phases import number_of_eulerian_discrete_phases
class multiphase(Group):
    """
    'multiphase' child.
    """

    fluent_name = "multiphase"

    child_names = \
        ['models', 'vaporization_pressure', 'non_condensable_gas',
         'liquid_surface_tension', 'bubble_number_density',
         'number_of_phases', 'number_of_eulerian_discrete_phases']

    models: models = models
    """
    models child of multiphase.
    """
    vaporization_pressure: vaporization_pressure = vaporization_pressure
    """
    vaporization_pressure child of multiphase.
    """
    non_condensable_gas: non_condensable_gas = non_condensable_gas
    """
    non_condensable_gas child of multiphase.
    """
    liquid_surface_tension: liquid_surface_tension = liquid_surface_tension
    """
    liquid_surface_tension child of multiphase.
    """
    bubble_number_density: bubble_number_density = bubble_number_density
    """
    bubble_number_density child of multiphase.
    """
    number_of_phases: number_of_phases = number_of_phases
    """
    number_of_phases child of multiphase.
    """
    number_of_eulerian_discrete_phases: number_of_eulerian_discrete_phases = number_of_eulerian_discrete_phases
    """
    number_of_eulerian_discrete_phases child of multiphase.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .conjugate_heat_transfer import conjugate_heat_transfer
from .solve import solve
class multidomain(Group):
    """
    'multidomain' child.
    """

    fluent_name = "multidomain"

    child_names = \
        ['conjugate_heat_transfer', 'solve']

    conjugate_heat_transfer: conjugate_heat_transfer = conjugate_heat_transfer
    """
    conjugate_heat_transfer child of multidomain.
    """
    solve: solve = solve
    """
    solve child of multidomain.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .area import area
from .depth import depth
from .density_6 import density
from .enthalpy import enthalpy
from .length import length
from .pressure import pressure
from .temperature_3 import temperature
from .yplus import yplus
from .velocity_2 import velocity
from .viscosity_3 import viscosity
from .zone import zone
from .compute import compute
from .list_val import list_val
class reference_values(Group):
    """
    'reference_values' child.
    """

    fluent_name = "reference-values"

    child_names = \
        ['area', 'depth', 'density', 'enthalpy', 'length', 'pressure',
         'temperature', 'yplus', 'velocity', 'viscosity', 'zone']

    area: area = area
    """
    area child of reference_values.
    """
    depth: depth = depth
    """
    depth child of reference_values.
    """
    density: density = density
    """
    density child of reference_values.
    """
    enthalpy: enthalpy = enthalpy
    """
    enthalpy child of reference_values.
    """
    length: length = length
    """
    length child of reference_values.
    """
    pressure: pressure = pressure
    """
    pressure child of reference_values.
    """
    temperature: temperature = temperature
    """
    temperature child of reference_values.
    """
    yplus: yplus = yplus
    """
    yplus child of reference_values.
    """
    velocity: velocity = velocity
    """
    velocity child of reference_values.
    """
    viscosity: viscosity = viscosity
    """
    viscosity child of reference_values.
    """
    zone: zone = zone
    """
    zone child of reference_values.
    """
    command_names = \
        ['compute', 'list_val']

    compute: compute = compute
    """
    compute command of reference_values.
    """
    list_val: list_val = list_val
    """
    list_val command of reference_values.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .normalization import normalization
from .integrate_over import integrate_over
from .report_type import report_type
from .average_over import average_over
from .per_zone import per_zone
from .old_props import old_props
from .thread_names import thread_names
from .thread_ids import thread_ids
class aeromechanics_child(Group):
    """
    'child_object_type' of aeromechanics.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['normalization', 'integrate_over', 'report_type', 'average_over',
         'per_zone', 'old_props', 'thread_names', 'thread_ids']

    normalization: normalization = normalization
    """
    normalization child of aeromechanics_child.
    """
    integrate_over: integrate_over = integrate_over
    """
    integrate_over child of aeromechanics_child.
    """
    report_type: report_type = report_type
    """
    report_type child of aeromechanics_child.
    """
    average_over: average_over = average_over
    """
    average_over child of aeromechanics_child.
    """
    per_zone: per_zone = per_zone
    """
    per_zone child of aeromechanics_child.
    """
    old_props: old_props = old_props
    """
    old_props child of aeromechanics_child.
    """
    thread_names: thread_names = thread_names
    """
    thread_names child of aeromechanics_child.
    """
    thread_ids: thread_ids = thread_ids
    """
    thread_ids child of aeromechanics_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .session_name import session_name
from .port import port
from .port_span import port_span
from .address import address
class start(Command):
    """
    'start' command.
    
    Parameters
    ----------
        session_name : str
            'session_name' child.
        port : int
            'port' child.
        port_span : int
            'port_span' child.
        address : str
            'address' child.
    
    """

    fluent_name = "start"

    argument_names = \
        ['session_name', 'port', 'port_span', 'address']

    session_name: session_name = session_name
    """
    session_name argument of start.
    """
    port: port = port
    """
    port argument of start.
    """
    port_span: port_span = port_span
    """
    port_span argument of start.
    """
    address: address = address
    """
    address argument of start.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .graphics import graphics
from .scene import scene
from .surfaces_2 import surfaces
from .animations import animations
from .plot_2 import plot
from .report_1 import report
class results(Group):
    """
    'results' child.
    """

    fluent_name = "results"

    child_names = \
        ['graphics', 'scene', 'surfaces', 'animations', 'plot', 'report']

    graphics: graphics = graphics
    """
    graphics child of results.
    """
    scene: scene = scene
    """
    scene child of results.
    """
    surfaces: surfaces = surfaces
    """
    surfaces child of results.
    """
    animations: animations = animations
    """
    animations child of results.
    """
    plot: plot = plot
    """
    plot child of results.
    """
    report: report = report
    """
    report child of results.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class adjust_solver_defaults_based_on_setup(Boolean):
    """
    Enable/disable adjustment of solver defaults based on setup.
    """

    fluent_name = "adjust-solver-defaults-based-on-setup"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

class set_dynamic_strength_exponent(Real):
    """
    Set cosine exponent in dynamic strength treatment.
    """

    fluent_name = "set-dynamic-strength-exponent"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .option_2 import option
from .volume_magnitude import volume_magnitude
from .volume_change import volume_change
class volume(Group):
    """
    'volume' child.
    """

    fluent_name = "volume"

    child_names = \
        ['option', 'volume_magnitude', 'volume_change']

    option: option = option
    """
    option child of volume.
    """
    volume_magnitude: volume_magnitude = volume_magnitude
    """
    volume_magnitude child of volume.
    """
    volume_change: volume_change = volume_change
    """
    volume_change child of volume.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .wall_distance_free import wall_distance_free
from .cjet import cjet
from .creal import creal
from .cnw_sub import cnw_sub
from .cjet_aux import cjet_aux
from .cbf_lam import cbf_lam
from .cbf_tur import cbf_tur
from .geko_defaults import geko_defaults
class geko_options(Group):
    """
    'geko_options' child.
    """

    fluent_name = "geko-options"

    child_names = \
        ['wall_distance_free', 'cjet', 'creal', 'cnw_sub', 'cjet_aux',
         'cbf_lam', 'cbf_tur']

    wall_distance_free: wall_distance_free = wall_distance_free
    """
    wall_distance_free child of geko_options.
    """
    cjet: cjet = cjet
    """
    cjet child of geko_options.
    """
    creal: creal = creal
    """
    creal child of geko_options.
    """
    cnw_sub: cnw_sub = cnw_sub
    """
    cnw_sub child of geko_options.
    """
    cjet_aux: cjet_aux = cjet_aux
    """
    cjet_aux child of geko_options.
    """
    cbf_lam: cbf_lam = cbf_lam
    """
    cbf_lam child of geko_options.
    """
    cbf_tur: cbf_tur = cbf_tur
    """
    cbf_tur child of geko_options.
    """
    command_names = \
        ['geko_defaults']

    geko_defaults: geko_defaults = geko_defaults
    """
    geko_defaults command of geko_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .iter_count_3 import iter_count
class iterate(Command):
    """
    Perform a specified number of iterations.
    
    Parameters
    ----------
        iter_count : int
            Set incremental number of time steps.
    
    """

    fluent_name = "iterate"

    argument_names = \
        ['iter_count']

    iter_count: iter_count = iter_count
    """
    iter_count argument of iterate.
    """
